@@ -22,6 +22,7 @@
 #' @param  block           Optimized block to be read into memory.
 #' @param  roi             Region of interest.
 #' @param  filter_fn       Smoothing filter function to be applied to the data.
+#' @param  impute_fn       Imputation function.
 #' @param  output_dir      Output directory.
 #' @param  version         Version of result.
 #' @param  verbose         Print processing information?
@@ -33,22 +34,22 @@
                            block,
                            roi,
                            filter_fn,
+                           impute_fn,
                            output_dir,
                            version,
                            verbose,
                            progress) {
     # Output file
     out_file <- .file_derived_name(
-        tile = tile, band = band, version = version, output_dir = output_dir
+        tile = tile,
+        band = band,
+        version = version,
+        output_dir = output_dir
     )
     # Resume feature
     if (file.exists(out_file)) {
         if (.check_messages()) {
-            message("Recovery: tile '", tile[["tile"]], "' already exists.")
-            message(
-                "(If you want to produce a new image, please ",
-                "change 'output_dir' or 'version' parameters)"
-            )
+            .check_recovery(out_file)
         }
         probs_tile <- .tile_derived_from_file(
             file = out_file,
@@ -61,16 +62,26 @@
         return(probs_tile)
     }
     # Show initial time for tile classification
-    tile_start_time <- .tile_classif_start(tile, verbose)
+    tile_start_time <- .tile_classif_start(
+        tile = tile,
+        verbose = verbose
+    )
     # Create chunks as jobs
-    chunks <- .tile_chunks_create(tile = tile, overlap = 0, block = block)
+    chunks <- .tile_chunks_create(
+        tile = tile,
+        overlap = 0,
+        block = block
+    )
     # By default, update_bbox is FALSE
     update_bbox <- FALSE
     if (.has(roi)) {
         # How many chunks there are in tile?
         nchunks <- nrow(chunks)
         # Intersecting chunks with ROI
-        chunks <- .chunks_filter_spatial(chunks, roi = roi)
+        chunks <- .chunks_filter_spatial(
+            chunks = chunks,
+            roi = roi
+        )
         # Should bbox of resulting tile be updated?
         update_bbox <- nrow(chunks) != nchunks
     }
@@ -94,7 +105,9 @@
         values <- .classify_data_read(
             tile = tile,
             block = block,
+            bands = .ml_bands(ml_model),
             ml_model = ml_model,
+            impute_fn = impute_fn,
             filter_fn = filter_fn
         )
         # Get mask of NA pixels
@@ -102,7 +115,7 @@
         # Fill with zeros remaining NA pixels
         values <- C_fill_na(values, 0)
         # Used to check values (below)
-        input_pixels <- nrow(values)
+        n_input_pixels <- nrow(values)
         # Log here
         .debug_log(
             event = "start_block_data_classification",
@@ -111,12 +124,11 @@
         )
         # Apply the classification model to values
         values <- ml_model(values)
-        # Clean the torch cache
-        if (torch::cuda_is_available()) {
-            torch::cuda_empty_cache()
-        }
         # Are the results consistent with the data input?
-        .check_processed_values(values, input_pixels)
+        .check_processed_values(
+            values = values,
+            n_input_pixels = n_input_pixels
+        )
         # Log
         .debug_log(
             event = "end_block_data_classification",
@@ -125,7 +137,8 @@
         )
         # Prepare probability to be saved
         band_conf <- .conf_derived_band(
-            derived_class = "probs_cube", band = band
+            derived_class = "probs_cube",
+            band = band
         )
         offset <- .offset(band_conf)
         if (.has(offset) && offset != 0) {
@@ -136,13 +149,9 @@
             values <- values / scale
             probs_fractions  <- probs_fractions / scale
         }
-
         # Mask NA pixels with same probabilities for all classes
         values[na_mask, ] <- probs_fractions
-
-        #
-        # Log here
-        #
+        # Log
         .debug_log(
             event = "start_block_data_save",
             key = "file",
@@ -181,7 +190,15 @@
         update_bbox = update_bbox
     )
     # show final time for classification
-    .tile_classif_end(tile, tile_start_time, verbose)
+    .tile_classif_end(
+        tile = tile,
+        start_time = tile_start_time,
+        verbose = verbose
+    )
+    # Clean torch allocations
+    if (.is_torch_model(ml_model)) {
+        torch::cuda_empty_cache()
+    }
     # Return probs tile
     probs_tile
 }
@@ -206,7 +223,10 @@
 #'
 #' @param  tile       Single tile of a data cube.
 #' @param  ml_model   Model trained by \code{\link[sits]{sits_train}}.
+#' @param  block      Optimized block to be read into memory.
+#' @param  roi        Region of interest.
 #' @param  filter_fn  Smoothing filter function to be applied to the data.
+#' @param  impute_fn  Imputation function to remove NA values.
 #' @param  n_sam_pol  Number of samples per polygon to be read
 #'                    for POLYGON or MULTIPOLYGON shapefiles or sf objects.
 #' @param  multicores Number of cores to be used for classification
@@ -217,7 +237,10 @@
 #' @return List of the classified raster layers.
 .classify_vector_tile <- function(tile,
                                   ml_model,
+                                  block,
+                                  roi,
                                   filter_fn,
+                                  impute_fn,
                                   n_sam_pol,
                                   multicores,
                                   memsize,
@@ -236,11 +259,7 @@
     # Resume feature
     if (.segments_is_valid(out_file)) {
         if (.check_messages()) {
-            message("Recovery: tile '", tile[["tile"]], "' already exists.")
-            message(
-                "(If you want to produce a new image, please ",
-                "change 'output_dir' or 'version' parameters)"
-            )
+            .check_recovery(out_file)
         }
         # Create tile based on template
         probs_tile <- .tile_segments_from_file(
@@ -253,35 +272,85 @@
         )
         return(probs_tile)
     }
-    # Get tile bands
-    bands <- .tile_bands(tile, add_cloud = FALSE)
-    segments_ts <- .segments_extract_multicores(
+    # Create chunks as jobs
+    chunks <- .tile_chunks_create(
         tile = tile,
-        bands = bands,
-        pol_id = "pol_id",
-        n_sam_pol = n_sam_pol,
-        multicores = multicores,
-        memsize = memsize,
-        output_dir = output_dir,
-        progress = FALSE
+        overlap = 0,
+        block = block
     )
-    # Classify segments
-    classified_ts <- .classify_ts(
-        samples = segments_ts,
-        ml_model = ml_model,
-        filter_fn = filter_fn,
-        multicores = multicores,
-        gpu_memory = gpu_memory,
-        progress = progress
-    )
-    # Join probability values with segments
-    joined_segments <- .segments_join_probs(
-        data = classified_ts,
-        segments = .segments_read_vec(tile),
-        aggregate = .has(n_sam_pol)
+    # By default, update_bbox is FALSE
+    if (.has(roi)) {
+        # How many chunks there are in tile?
+        nchunks <- nrow(chunks)
+        # Intersecting chunks with ROI
+        chunks <- .chunks_filter_spatial(
+            chunks = chunks,
+            roi = roi
+        )
+        # Should bbox of resulting tile be updated?
+        update_bbox <- nrow(chunks) != nchunks
+    } else {
+        update_bbox <- FALSE
+    }
+    # Filter segments that intersects with each chunk
+    chunks <- .chunks_filter_segments(
+        chunks = chunks,
+        tile = tile,
+        output_dir = output_dir
     )
+    on.exit(unlink(unlist(chunks[["segments"]])))
+    # Process jobs in parallel
+    block_files <- .jobs_map_parallel_chr(chunks, function(chunk) {
+        # Job block
+        block <- .block(chunk)
+        # Block file name
+        block_file <- .file_block_name(
+            pattern = .file_pattern(out_file),
+            block = block,
+            output_dir = output_dir,
+            ext = "gpkg"
+        )
+        # Resume processing in case of failure
+        if (.segments_is_valid(block_file)) {
+            return(block_file)
+        }
+        # Extract segments time series
+        segments_ts <- .segments_poly_read(
+            tile = tile,
+            chunk = chunk,
+            n_sam_pol = n_sam_pol,
+            impute_fn = impute_fn
+        )
+        # Classify segments
+        segments_ts <- .classify_ts(
+            samples = segments_ts,
+            ml_model = ml_model,
+            filter_fn = filter_fn,
+            impute_fn = impute_fn,
+            multicores = 1,
+            gpu_memory = gpu_memory,
+            progress = FALSE
+        )
+        # Join probability values with segments
+        segments_ts <- .segments_join_probs(
+            data = segments_ts,
+            segments = .segments_read_vec(tile)
+        )
+        # Write segment block
+        .vector_write_vec(
+            v_obj = segments_ts,
+            file_path = block_file
+        )
+        # Free memory
+        gc()
+        # Return block file
+        return(block_file)
+    }, progress = progress)
+    # Read all segments
+    segments_ts <- purrr::map(block_files, .vector_read_vec)
+    segments_ts <- dplyr::bind_rows(segments_ts)
     # Write all segments
-    .vector_write_vec(v_obj = joined_segments, file_path = out_file)
+    .vector_write_vec(v_obj = segments_ts, file_path = out_file)
     # Create tile based on template
     probs_tile <- .tile_segments_from_file(
         file = out_file,
@@ -291,6 +360,8 @@
         vector_class = "probs_vector_cube",
         update_bbox = FALSE
     )
+    # Remove file block
+    unlink(block_files)
     # Return probability vector tile
     return(probs_tile)
 }
@@ -304,19 +375,29 @@
 #'
 #' @param  tile            Input tile to read data.
 #' @param  block           Bounding box in (col, row, ncols, nrows).
+#' @param  bands           Bands to extract time series
 #' @param  ml_model        Model trained by \code{\link[sits]{sits_train}}.
+#' @param  impute_fn       Imputation function
 #' @param  filter_fn       Smoothing filter function to be applied to the data.
 #' @return A matrix with values for classification.
-.classify_data_read <- function(tile, block, ml_model, filter_fn) {
+.classify_data_read <- function(tile, block, bands,
+                                ml_model, impute_fn, filter_fn) {
     # For cubes that have a time limit to expire (MPC cubes only)
     tile <- .cube_token_generator(tile)
     # Read and preprocess values of cloud
     # Get cloud values (NULL if not exists)
-    cloud_mask <- .tile_cloud_read_block(tile = tile, block = block)
+    cloud_mask <- .tile_cloud_read_block(
+        tile = tile,
+        block = block
+    )
     # Read and preprocess values of each band
-    values <- purrr::map(.ml_bands(ml_model), function(band) {
+    values <- purrr::map(bands, function(band) {
         # Get band values (stops if band not found)
-        values <- .tile_read_block(tile = tile, band = band, block = block)
+        values <- .tile_read_block(
+            tile = tile,
+            band = band,
+            block = block
+        )
         # Log
         .debug_log(
             event = "start_block_data_process",
@@ -327,10 +408,8 @@
         if (.has(cloud_mask)) {
             values[cloud_mask] <- NA
         }
-        # use linear imputation
-        impute_fn <- .impute_linear()
         # are there NA values? interpolate them
-        if (any(is.na(values))) {
+        if (anyNA(values)) {
             values <- impute_fn(values)
         }
         # Filter the time series
@@ -365,7 +444,9 @@
     # Compose final values
     values <- as.matrix(values)
     # Set values features name
-    colnames(values) <- .ml_features_name(ml_model)
+    if (.has(ml_model)) {
+        colnames(values) <- .ml_features_name(ml_model)
+    }
     # Return values
     values
 }
@@ -380,6 +461,7 @@
 #' @param  samples    a tibble with sits samples
 #' @param  ml_model   model trained by \code{\link[sits]{sits_train}}.
 #' @param  filter_fn  Smoothing filter to be applied (if desired).
+#' @param  impute_fn  Imputation function (to remove NA)
 #' @param  multicores number of threads to process the time series.
 #' @param  gpu_memory Memory available in GPU
 #' @param  progress   Show progress bar?
@@ -387,6 +469,7 @@
 .classify_ts <- function(samples,
                          ml_model,
                          filter_fn,
+                         impute_fn,
                          multicores,
                          gpu_memory,
                          progress) {
@@ -397,15 +480,29 @@
     bands <- .ml_bands(ml_model)
     # Update samples bands order
     if (any(bands != .samples_bands(samples))) {
-        samples <- .samples_select_bands(samples = samples, bands = bands)
+        samples <- .samples_select_bands(
+            samples = samples,
+            bands = bands
+        )
     }
     # Apply time series filter
-    if (!purrr::is_null(filter_fn)) {
-        samples <- .apply_across(data = samples, fn = filter_fn)
+    if (.has(filter_fn)) {
+        samples <- .apply_across(
+            data = samples,
+            fn = filter_fn
+        )
+    }
+    # Apply imputation filter
+    if (.has(impute_fn)) {
+        samples <- .apply_across(
+            data = samples,
+            fn = impute_fn
+        )
     }
     # Compute the breaks in time for multiyear classification
     class_info <- .timeline_class_info(
-        data = samples, samples = .ml_samples(ml_model)
+        data = samples,
+        samples = .ml_samples(ml_model)
     )
     # Split long time series of samples in a set of small time series
     if (length(class_info[["dates_index"]][[1]]) > 1) {
@@ -413,18 +510,35 @@
             samples = samples,
             split_intervals = class_info[["dates_index"]][[1]]
         )
-        pred <- .predictors(samples = splitted, ml_model = ml_model)
+        pred <- .predictors(
+            samples = splitted,
+            ml_model = ml_model
+        )
         # Post condition: is predictor data valid?
-        .check_predictors(pred, splitted)
+        .check_predictors(
+            pred = pred,
+            samples = splitted
+        )
     } else {
         # Convert samples time series in predictors and preprocess data
-        pred <- .predictors(samples = samples, ml_model = ml_model)
+        pred <- .predictors(
+            samples = samples,
+            ml_model = ml_model
+        )
     }
     # choose between GPU and CPU
-    if ("torch_model" %in% class(ml_model) && torch::cuda_is_available())
-        prediction <- .classify_ts_gpu(pred, ml_model, gpu_memory)
+    if (inherits(ml_model, "torch_model") && torch::cuda_is_available())
+        prediction <- .classify_ts_gpu(
+            pred = pred,
+            ml_model = ml_model,
+            gpu_memory = gpu_memory)
     else
-        prediction <- .classify_ts_cpu(pred, ml_model, multicores, progress)
+        prediction <- .classify_ts_cpu(
+            pred = pred,
+            ml_model = ml_model,
+            multicores = multicores,
+            progress = progress
+        )
     # Store the result in the input data
     if (length(class_info[["dates_index"]][[1]]) > 1) {
         prediction <- .tibble_prediction_multiyear(
@@ -457,10 +571,13 @@
 .classify_ts_cpu <- function(pred,
                              ml_model,
                              multicores,
-                             progress){
+                             progress) {
 
     # Divide samples predictors in chunks to parallel processing
-    parts <- .pred_create_partition(pred = pred, partitions = multicores)
+    parts <- .pred_create_partition(
+        pred = pred,
+        partitions = multicores
+    )
     # Do parallel process
     prediction <- .jobs_map_parallel_dfr(parts, function(part) {
         # Get predictors of a given partition
@@ -490,14 +607,19 @@
 #' @return A tibble with the predicted values.
 .classify_ts_gpu <- function(pred,
                              ml_model,
-                             gpu_memory){
+                             gpu_memory) {
     # estimate size of GPU memory required (in GB)
-    pred_size <- nrow(pred) * ncol(pred) * 4 * .conf("processing_bloat_gpu")/1e+09
+    pred_size <- nrow(pred) * ncol(pred) * 4 / 1e+09
+    # include processing bloat
+    pred_size <- pred_size * .conf("processing_bloat_gpu")
     # estimate how should we partition the predictors
-    num_parts <- ceiling(pred_size/gpu_memory)
+    num_parts <- ceiling(pred_size / gpu_memory)
     # Divide samples predictors in chunks to parallel processing
-    parts <- .pred_create_partition(pred = pred, partitions = num_parts)
-    prediction <- slider::slide_dfr(parts, function(part){
+    parts <- .pred_create_partition(
+        pred = pred,
+        partitions = num_parts
+    )
+    prediction <- slider::slide_dfr(parts, function(part) {
         # Get predictors of a given partition
         pred_part <- .pred_part(part)
         # Get predictors features to classify
@@ -512,5 +634,42 @@
     })
     return(prediction)
 }
-
-
+#' @title Start recording processing time
+#' @name .classify_verbose_start
+#' @keywords internal
+#' @noRd
+#' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
+#' @description Prints the block size and computes
+#' start time for processing
+#'
+#' @param  verbose TRUE/FALSE
+#' @param  block   block size
+#' @return start time for processing
+.classify_verbose_start <- function(verbose, block) {
+    start_time <- Sys.time()
+    if (verbose) {
+        msg <- paste0(.conf("messages", ".verbose_block_size"), " ",
+                      .nrows(block), " x ", .ncols(block))
+        message(msg)
+    }
+    return(start_time)
+}
+#' @title End recording processing time
+#' @name .classify_verbose_end
+#' @keywords internal
+#' @noRd
+#' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
+#' @description Prints the processing time
+#' @param  verbose TRUE/FALSE
+#' @param  start_time   initial processing time
+#' @return elapsed processing time for processing
+.classify_verbose_end <- function(verbose, start_time) {
+    if (verbose) {
+        end_time <- Sys.time()
+        message("")
+        message(.conf("messages", ".verbose_task_end"), end_time)
+        message(.conf("messages", ".verbose_task_elapsed"),
+                format(round(end_time - start_time, digits = 2))
+        )
+    }
+}
