@@ -94,8 +94,14 @@
                                 progress) {
     # Create band date as jobs
     band_date_cube <- .mosaic_split_band_date(cube)
+    # Get band configs from tile
+    band_conf <- .tile_band_conf(.tile(cube), band = .cube_bands(cube))
+    # Get cube file paths
+    cube_files <- unlist(.cube_paths(cube))
+    on.exit(unlink(cube_files))
     # Process jobs in parallel
     mosaic_cube <- .jobs_map_parallel_dfr(band_date_cube, function(job) {
+        # Get cube as a job
         cube <- job[["cube"]][[1]]
         # Get cube file paths
         cube_files <- unlist(.cube_paths(cube))
@@ -112,11 +118,7 @@
         # Resume feature
         if (.raster_is_valid(out_file, output_dir = output_dir)) {
             if (.check_messages()) {
-                message("Recovery: file '", out_file, "' already exists.")
-                message(
-                    "(If you want to produce a new cropped image, please ",
-                    "change 'version' or 'output_dir' parameter)"
-                )
+                .check_recovery(out_file)
             }
             base_tile <- .tile_from_file(
                 file = out_file, base_tile = base_tile,
@@ -131,13 +133,13 @@
             file = out_file,
             base_files = cube_files,
             params = list(
-                "-ot" = .gdal_data_type[["INT1U"]],
+                "-ot" = .gdal_data_type[[.data_type(band_conf)]],
                 "-of" = .conf("gdal_presets", "image", "of"),
                 "-co" = .conf("gdal_presets", "image", "co"),
                 "-t_srs" = .as_crs(crs),
                 "-wo" = paste0("NUM_THREADS=", multicores),
-                "-multi" = TRUE,
-                "-srcnodata" = 255
+                "-multi" = FALSE,
+                "-srcnodata" = .miss_value(band_conf)
             ),
             quiet = TRUE
         )
@@ -149,8 +151,6 @@
             band = .tile_bands(base_tile), update_bbox = TRUE,
             labels = .tile_labels(base_tile)
         )
-        # Delete cube files
-        #unlink(cube_files)
         # Return cube
         return(base_tile)
     }, progress = progress)
@@ -175,13 +175,7 @@
     )
     # Resume feature
     if (.raster_is_valid(out_file, output_dir = output_dir)) {
-        if (.check_messages()) {
-            message("Recovery: file '", out_file, "' already exists.")
-            message(
-                "(If you want to produce a new cropped image, please ",
-                "change 'version' or 'output_dir' parameter)"
-            )
-        }
+        .check_recovery(out_file)
         asset <- .tile_from_file(
             file = out_file, base_tile = asset,
             band = .tile_bands(asset), update_bbox = TRUE,
@@ -197,10 +191,10 @@
         out_file = out_file,
         src_min = .min_value(band_conf),
         src_max = .max_value(band_conf),
-        dst_min = 0,
-        dst_max = 254,
-        miss_value = 255,
-        data_type = "INT1U"
+        dst_min = .min_value(band_conf),
+        dst_max = .max_value(band_conf),
+        miss_value = .miss_value(band_conf),
+        data_type = .data_type(band_conf)
     )
     # If the asset is fully contained in roi it's not necessary to crop it
     if (.has(roi)) {
@@ -212,8 +206,8 @@
                 file = out_file, out_file = out_file,
                 crs = .as_crs(.tile_crs(asset)),
                 as_crs = .mosaic_crs(tile = asset, as_crs = crs),
-                miss_value = 255,
-                data_type = "INT1U",
+                miss_value = .miss_value(band_conf),
+                data_type = .data_type(band_conf),
                 multicores = 1,
                 overwrite = TRUE
             )
@@ -237,8 +231,8 @@
         out_file = out_file,
         roi_file = roi,
         as_crs = .mosaic_crs(tile = asset, as_crs = crs),
-        miss_value = 255,
-        data_type = "INT1U",
+        miss_value = .miss_value(band_conf),
+        data_type = .data_type(band_conf),
         multicores = 1,
         overwrite = TRUE
     )
@@ -274,7 +268,7 @@
 #' @param  tile         Tile of data cube
 #' @return              BDC or RASTER
 .mosaic_type <- function(tile) {
-    if (.cube_source(tile) %in% "BDC") {
+    if (.cube_source(tile) == "BDC") {
         return("BDC")
     }
     return("RASTER")
@@ -285,9 +279,7 @@
 #' @param  tile         Tile of data cube
 #' @return              Result dependent on the type
 .mosaic_switch <- function(tile, ...) {
-    switch(.mosaic_type(tile),
-        ...
-    )
+    switch(.mosaic_type(tile), ...)
 }
 #' @title Get mosaic CRS
 #' @keywords internal
@@ -297,10 +289,10 @@
 .mosaic_crs <- function(tile, as_crs) {
     .mosaic_switch(
         tile,
-        "BDC" = .as_crs("+proj=aea
+        BDC = .as_crs("+proj=aea
                         +lat_0=-12 +lon_0=-54 +lat_1=-2 +lat_2=-22
                         +x_0=5000000 +y_0=10000000
                         +ellps=GRS80 +units=m +no_defs "),
-        "RASTER" = .as_crs(as_crs)
+        RASTER = .as_crs(as_crs)
     )
 }
