@@ -9,8 +9,10 @@
 #' @param start_date      Start date for the data set.
 #' @param end_date        End date for the data set.
 #' @param n_sam_pol       Number of samples per polygon to be read.
-#' @param pol_id          ID attribute for polygons shapefile.
+#' @param pol_id          ID attribute which contains label
 #'                        (for POLYGON or MULTIPOLYGON shapefile).
+#' @param sampling_type   Spatial sampling type: random, hexagonal,
+#'                        regular, or Fibonacci.
 #' @return                A tibble with information the samples to be retrieved.
 #'
 .sf_get_samples <- function(sf_object,
@@ -19,24 +21,17 @@
                             start_date,
                             end_date,
                             n_sam_pol,
-                            pol_id) {
+                            pol_id,
+                            sampling_type) {
+    # set caller to show in errors
+    .check_set_caller(".sf_get_samples")
     # Pre-condition - is the sf object has geometries?
-    .check_that(
-        x = nrow(sf_object) > 0,
-        msg = "sf object has no geometries"
-    )
+    .check_that(nrow(sf_object) > 0)
     # Precondition - can the function deal with the geometry_type?
-    .check_chr_within(
-        x = as.character(sf::st_geometry_type(sf_object)[1]),
-        within = .conf("sf_geom_types_supported"),
-        discriminator = "one_of",
-        msg = paste0(
-            "Only handles with geometry types: ", paste(
-                .conf("sf_geom_types_supported"),
-                collapse = ", "
-            )
-        )
-    )
+    geom_type <- as.character(sf::st_geometry_type(sf_object)[[1]])
+    sf_geom_types_supported <- .conf("sf_geom_types_supported")
+    .check_that(geom_type %in% sf_geom_types_supported)
+
     # Get the points to be read
     samples <- .sf_to_tibble(
         sf_object  = sf_object,
@@ -44,10 +39,10 @@
         label      = label,
         n_sam_pol  = n_sam_pol,
         pol_id     = pol_id,
+        sampling_type = sampling_type,
         start_date = start_date,
         end_date   = end_date
     )
-
     class(samples) <- c("sits", class(samples))
 
     return(samples)
@@ -60,22 +55,25 @@
 #' @description reads a shapefile and retrieves a sits tibble
 #' containing a set of lat/long points for data retrieval
 #'
-#' @param sf_object  sf object .
-#' @param label_attr Attribute in sf object used as a polygon label.
-#' @param label      Label to be assigned to points.
-#' @param n_sam_pol  Number of samples per polygon to be read
-#'                   (for POLYGON or MULTIPOLYGON shapes).
-#' @param  pol_id    ID attribute for polygons.
-#' @param start_date Start of the interval for the time series
-#'                   in "YYYY-MM-DD" format (optional).
-#' @param end_date   End of the interval for the time series in
-#'                   "YYYY-MM-DD" format (optional).
+#' @param sf_object       sf object.
+#' @param label_attr      Attribute in sf object used as a polygon label.
+#' @param label           Label to be assigned to points.
+#' @param n_sam_pol       Number of samples per polygon to be read
+#'                        (for POLYGON or MULTIPOLYGON shapes).
+#' @param pol_id          ID attribute for polygons which contains the label
+#' @param sampling_type   Spatial sampling type: random, hexagonal,
+#'                        regular, or Fibonacci.
+#' @param start_date      Start of the interval for the time series
+#'                        in "YYYY-MM-DD" format (optional).
+#' @param end_date        End of the interval for the time series in
+#'                        "YYYY-MM-DD" format (optional).
 #' @return  A sits tibble with points to to be read.
 .sf_to_tibble <- function(sf_object,
                           label_attr,
                           label,
                           n_sam_pol,
                           pol_id,
+                          sampling_type,
                           start_date,
                           end_date) {
 
@@ -83,32 +81,34 @@
     are_empty_geoms <- sf::st_is_empty(sf_object)
     if (any(are_empty_geoms)) {
         if (.check_warnings()) {
-            warning(
-                "Some empty geometries were removed.",
+            warning(.conf("messages", ".sf_to_tibble"),
                 immediate. = TRUE, call. = FALSE
             )
         }
         sf_object <- sf_object[!are_empty_geoms, ]
     }
     # If the sf object is not in planar coordinates, convert it
-    sf_object <- suppressWarnings(sf::st_transform(sf_object, crs = 4326))
+    sf_object <- suppressWarnings(
+        sf::st_transform(sf_object, crs = "EPSG:4326")
+    )
 
     # Get the geometry type
-    geom_type <- as.character(sf::st_geometry_type(sf_object)[1])
+    geom_type <- as.character(sf::st_geometry_type(sf_object)[[1]])
     # Get a tibble with points and labels
     points_tbl <- switch(geom_type,
-        "POINT" = .sf_point_to_tibble(
+        POINT = .sf_point_to_tibble(
             sf_object  = sf_object,
             label_attr = label_attr,
             label      = label
         ),
-        "POLYGON" = ,
-        "MULTIPOLYGON" = .sf_polygon_to_tibble(
+        POLYGON = ,
+        MULTIPOLYGON = .sf_polygon_to_tibble(
             sf_object  = sf_object,
             label_attr = label_attr,
             label      = label,
             n_sam_pol  = n_sam_pol,
-            pol_id     = pol_id
+            pol_id     = pol_id,
+            sampling_type = sampling_type
         )
     )
 
@@ -140,7 +140,7 @@
 
     if ("label" %in% colnames(sf_df)) {
         labels <- as.character(unlist(sf_df[, "label"], use.names = FALSE))
-    } else if (!purrr::is_null(label_attr)) {
+    } else if (.has(label_attr)) {
         .check_chr_within(
             x = label_attr,
             within = colnames(sf_df)
@@ -168,30 +168,31 @@
 #' @param label_attr      Attribute in the shapefile used as a polygon label
 #' @param label           Label to be assigned to points
 #' @param n_sam_pol       Number of samples per polygon to be read
-#' @param pol_id          ID attribute for polygons shapefile.
+#' @param pol_id          ID attribute for polygons containing the label
+#' @param sampling_type   Spatial sampling type: random, hexagonal,
+#'                        regular, or Fibonacci.
 #' @return A tibble with latitude/longitude points from POLYGON geometry
 #'
 .sf_polygon_to_tibble <- function(sf_object,
                                   label_attr,
                                   label,
                                   n_sam_pol,
-                                  pol_id) {
+                                  pol_id,
+                                  sampling_type) {
+    .check_set_caller(".sf_polygon_to_tibble")
     # get the db file
     sf_df <- sf::st_drop_geometry(sf_object)
 
-    if (!purrr::is_null(label_attr)) {
+    if (.has(label_attr)) {
         .check_chr_within(
             x = label_attr,
-            within = colnames(sf_df),
-            msg = "invalid 'label_attr' parameter."
+            within = colnames(sf_df)
         )
     }
-
-    if (!purrr::is_null(pol_id)) {
+    if (.has(pol_id)) {
         .check_chr_within(
             x = pol_id,
-            within = colnames(sf_df),
-            msg = "invalid 'pol_id' parameter."
+            within = colnames(sf_df)
         )
     }
     points_tab <- seq_len(nrow(sf_object)) |>
@@ -201,28 +202,30 @@
                 label <- as.character(
                     unlist(sf_df[i, "label"], use.names = FALSE)
                 )
-            } else if (!purrr::is_null(label_attr) &&
+            } else if (.has(label_attr) &&
                 label_attr %in% colnames(sf_df)) {
                 label <- as.character(
                     unlist(sf_df[i, label_attr], use.names = FALSE)
                 )
             }
-            if (!purrr::is_null(pol_id) && pol_id %in% colnames(sf_df)) {
+            if (.has(pol_id) && pol_id %in% colnames(sf_df)) {
                 polygon_id <- unname(as.character(sf_df[i, pol_id]))
             }
             # obtain a set of samples based on polygons
-            points <- list(sf::st_sample(sf_object[i, ], size = n_sam_pol))
+            points <- list(sf::st_sample(sf_object[i, ],
+                                         type = sampling_type,
+                                         size = n_sam_pol))
             # get one time series per sample
             pts_tab <- points |>
                 purrr::pmap_dfr(function(p) {
                     pll <- sf::st_geometry(p)[[1]]
                     row <- tibble::tibble(
-                        longitude = pll[1],
-                        latitude = pll[2],
+                        longitude = pll[[1]],
+                        latitude = pll[[2]],
                         label = label
                     )
 
-                    if (!purrr::is_null(pol_id) &&
+                    if (.has(pol_id) &&
                         pol_id %in% colnames(sf_df)) {
                         row <- tibble::add_column(
                             row,
