@@ -43,7 +43,7 @@
     # initialize vector items
     vector_items <- NULL
     # is this a cube with results?
-    results_cube <- .check_cube_is_results_cube(bands, labels)
+    results_cube <- .check_is_results_cube(bands, labels)
 
     # set the correct parse_info
     parse_info <- .conf_parse_info(parse_info, results_cube)
@@ -61,7 +61,7 @@
         end_date = end_date,
         bands = bands
     )
-    if (!purrr::is_null(vector_dir)) {
+    if (.has(vector_dir)) {
         # set the correct parse_info
         parse_info <- .conf("results_parse_info_def")
 
@@ -86,12 +86,12 @@
         )
     }
     # filter tiles
-    if (!purrr::is_null(tiles)) {
+    if (.has(tiles)) {
         raster_items <- .local_cube_items_tiles_select(
             tiles = tiles,
             items = raster_items
         )
-        if (!purrr::is_null(vector_items)) {
+        if (.has(vector_items)) {
             vector_items <- .local_cube_items_tiles_select(
                 tiles = tiles,
                 items = vector_items
@@ -137,7 +137,7 @@
             items = items_tile
         )
     })
-    if (!purrr::is_null(vector_items)) {
+    if (.has(vector_items)) {
         cube <- .local_cube_include_vector_info(cube, vector_items)
     }
 
@@ -149,9 +149,9 @@
         )
     } else {
         class(cube) <- .cube_s3class(cube)
-        if (!purrr::is_null(vector_items)) {
+        if (.has(vector_items)) {
             if (vector_band == "segments") {
-                class(cube) <- c("segs_cube","vector_cube", class(cube))
+                class(cube) <- c("segs_cube", "vector_cube", class(cube))
             } else if (vector_band == "probs") {
                 class(cube) <- c("probs_vector_cube",
                                  "derived_vector_cube",
@@ -199,7 +199,7 @@
     .check_set_caller(".local_cube_items_raster_new")
 
     # is this a cube with results?
-    if (!purrr::is_null(bands) &&
+    if (.has(bands) &&
         bands[[1]] %in% .conf("sits_results_bands")) {
         results_cube <- TRUE
     } else {
@@ -213,40 +213,30 @@
         path = data_dir,
         pattern = paste0("\\.(", paste0(file_ext, collapse = "|"), ")$")
     )
-    # post-condition
-    .check_chr(img_files,
-        allow_empty = FALSE, len_min = 1,
-        msg = "no file found in provided directory"
-    )
+    # postcondition
+    .check_chr_parameter(img_files, allow_empty = FALSE, len_min = 1)
 
     # remove the extension
     img_files_noext <- tools::file_path_sans_ext(img_files)
-
     # split the file names
     img_files_lst <- strsplit(img_files_noext, split = delim, fixed = TRUE)
-
+    # which image files in directory match the parse info?
     are_img_files_ok <- purrr::map_lgl(img_files_lst, function(img_file) {
-        if (length(img_file) == length(parse_info)) {
+        if (length(img_file) == length(parse_info))
             return(TRUE)
-        }
-        return(FALSE)
+        else
+            return(FALSE)
     })
-
+    # select the images that match the file info
     img_files_ok <- img_files_lst[are_img_files_ok]
 
     # post condition
-    .check_that(
-        length(img_files_ok) > 0,
-        local_msg = "no file matched fields of parse_info",
-        msg = "invalid file names or 'parse_info' parameter"
-    )
+    .check_that(length(img_files_ok) > 0)
 
-    # filtered only valid files
+    # get valid files
     img_files_filt <- img_files[are_img_files_ok]
-
     # bind rows
     img_files_mx <- do.call(rbind, img_files_ok)
-
     # read the image files into a tibble with added parse info
     colnames(img_files_mx) <- parse_info
     # joint the list into a tibble and convert bands name to upper case
@@ -255,13 +245,13 @@
             .name_repair = "universal"
         )
     )
-    if (!purrr::is_null(bands)) {
+    if (.has(bands)) {
         # check if bands exist
         .check_chr_contains(
-            x = items$band,
+            x = items[["band"]],
             contains = bands,
             discriminator = "all_of",
-            msg = "Wrong bands specification - please correct"
+            msg = .conf("messages", ".local_cube_items_bands")
         )
     }
     # get the information on the required bands, dates and path
@@ -269,9 +259,9 @@
         # check required version exists
         .check_chr_within(
             x = version,
-            within = items$version,
+            within = items[["version"]],
             discriminator = "any_of",
-            msg = "Wrong version specification - please correct"
+            msg = .conf("messages", ".local_cube_items_version")
         )
         # get only the first band
         band <- bands[[1]]
@@ -280,7 +270,8 @@
             # bands are case insensitive (converted to lower case)
             dplyr::mutate(band = tolower(.data[["band"]])) |>
             # add path
-            dplyr::mutate(path = paste(data_dir, img_files_filt, sep = "/")) |>
+            dplyr::mutate(path = paste(data_dir,
+                                           img_files_filt, sep = "/")) |>
             # filter by the band
             dplyr::filter(.data[["band"]] == !!band) |>
             # filter by the version
@@ -339,17 +330,15 @@
             dplyr::arrange(.data[["date"]], .data[["band"]])
 
         # filter start and end dates
-        if (!purrr::is_null(start_date)) {
+        if (.has(start_date)) {
             items <- dplyr::filter(items, .data[["date"]] >= start_date)
         }
-        if (!purrr::is_null(end_date)) {
+        if (.has(end_date)) {
             items <- dplyr::filter(items, .data[["date"]] <= end_date)
         }
     }
     # post-condition
-    .check_that(nrow(items) > 0,
-        msg = "no files found in the interval"
-    )
+    .check_that(nrow(items) > 0)
     return(items)
 }
 #' @title Return raster items for local data cube
@@ -382,38 +371,26 @@
         pattern = paste0("\\.(", paste0(file_ext, collapse = "|"), ")$")
     )
     # post-condition
-    .check_chr(gpkg_files,
-               allow_empty = FALSE, len_min = 1,
-               msg = "no vector files found in provided directory"
-    )
+    gpkg_files_path <- paste0(vector_dir, "/", gpkg_files)
+    .check_that(all(file.exists(gpkg_files_path)))
+
     # remove the extension
     gpkg_files_noext <- tools::file_path_sans_ext(gpkg_files)
-
     # split the file names
     gpkg_files_lst <- strsplit(gpkg_files_noext, split = delim, fixed = TRUE)
-
+    # check gkpg files
     are_gpkg_files_ok <- purrr::map_lgl(gpkg_files_lst, function(gpkg_file) {
         if (length(gpkg_file) == length(parse_info)) {
             return(TRUE)
         }
         return(FALSE)
     })
-
+    # subset gkpg files
     gpkg_files_ok <- gpkg_files_lst[are_gpkg_files_ok]
-
-    # post condition
-    .check_that(
-        length(gpkg_files_ok) > 0,
-        local_msg = "no file matches  parse_info fields",
-        msg = "invalid file names or 'parse_info' parameter"
-    )
-
     # filter only valid files
     gpkg_files_filt <- gpkg_files[are_gpkg_files_ok]
-
     # bind rows
     gpkg_files_mx <- do.call(rbind, gpkg_files_ok)
-
     # read the image files into a tibble with added parse info
     colnames(gpkg_files_mx) <- parse_info
     # joint the list into a tibble and convert bands name to upper case
@@ -424,25 +401,26 @@
     )
     # check if bands exist
     .check_chr_contains(
-        x = items$band,
+        x = items[["band"]],
         contains = vector_band,
         discriminator = "any_of",
-        msg = "Wrong vector band specification - please correct"
+        msg = .conf("messages", ".local_cube_items_bands")
     )
     # get the information on the required bands, dates and path
     # check required version exists
     .check_chr_within(
         x = version,
-        within = items$version,
+        within = items[["version"]],
         discriminator = "any_of",
-        msg = "Wrong version specification - please correct"
+        msg = .conf("messages", ".local_cube_items_version")
     )
     # get the information on the required band, dates and path
     items <- items |>
         # bands are case insensitive (converted to lower case)
         dplyr::mutate(band = tolower(.data[["band"]])) |>
         # add path
-        dplyr::mutate(path = paste(vector_dir, gpkg_files_filt, sep = "/")) |>
+        dplyr::mutate(path = paste(vector_dir,
+                                   gpkg_files_filt, sep = "/")) |>
         # filter by the band
         dplyr::filter(.data[["band"]] == !!vector_band) |>
         # filter by the version
@@ -475,9 +453,7 @@
         dplyr::arrange(.data[["start_date"]])
 
     # post-condition
-    .check_that(nrow(items) > 0,
-                msg = "no files found in the interval"
-    )
+    .check_that(nrow(items) > 0)
     return(items)
 }
 #' @title Select items by bands
@@ -496,7 +472,7 @@
                                            bands,
                                            items) {
     # set caller to show in errors
-    .check_set_caller(".local_cube_items_bands_select")
+    .check_set_caller(".local_cube_items_bands")
 
     # convert the band names to SITS bands
     items <- dplyr::mutate(
@@ -508,11 +484,10 @@
         )
     )
     # filter bands
-    if (!purrr::is_null(bands)) {
+    if (.has(bands)) {
         # verify that the requested bands exist
         .check_chr_within(bands,
-            within = unique(items[["band"]]),
-            msg = "invalid 'bands' value"
+            within = unique(items[["band"]])
         )
         # select the requested bands
         items <- dplyr::filter(items, .data[["band"]] %in% !!bands)
@@ -533,8 +508,7 @@
     # filter tiles
     # verify that the requested tiles exist
     .check_chr_within(tiles,
-        within = unique(items[["tile"]]),
-        msg = "invalid 'tiles' value"
+        within = unique(items[["tile"]])
     )
     # select the requested tiles
     items <- dplyr::filter(items, .data[["tile"]] %in% !!tiles)
@@ -554,9 +528,7 @@
     # set caller to show in errors
     .check_set_caller(".local_cube_file_info")
     # post-condition
-    .check_that(nrow(items) > 0,
-        msg = "invalid 'items' parameter"
-    )
+    .check_that(nrow(items) > 0)
     # add feature id (fid)
     items <- dplyr::group_by(items, .data[["tile"]], .data[["date"]]) |>
         dplyr::mutate(fid = paste0(dplyr::cur_group_id())) |>
@@ -603,9 +575,9 @@
     items <- purrr::map(results_lst, `[[`, "item")
     errors <- unlist(purrr::map(results_lst, `[[`, "error"))
     if (length(errors) > 0) {
-        warning("cannot open file(s): ",
-            paste0("'", errors, "'", collapse = ", "),
-            call. = FALSE, immediate. = TRUE
+        warning(.conf("messages", ".local_cube_file_info_error"),
+                toString(errors),
+                call. = FALSE, immediate. = TRUE
         )
     }
     items <- dplyr::bind_rows(items) |>
@@ -625,9 +597,7 @@
     .check_set_caller(".local_results_cube_file_info")
 
     # post-condition
-    .check_that(nrow(items) > 0,
-        msg = "invalid 'items' parameter"
-    )
+    .check_that(nrow(items) > 0)
 
     # prepare parallel requests
     if (is.null(sits_env[["cluster"]])) {
@@ -673,9 +643,9 @@
     items_lst <- purrr::map(results_lst, `[[`, "item")
     errors <- unlist(purrr::map(results_lst, `[[`, "error"))
     if (length(errors) > 0) {
-        warning("cannot open file(s):",
-            paste0("'", errors, "'", collapse = ", "),
-            call. = FALSE, immediate. = TRUE
+        warning(.conf("messages", ".local_cube_file_info_error"),
+                toString(errors),
+                call. = FALSE, immediate. = TRUE
         )
     }
     items <- dplyr::bind_rows(items_lst)
@@ -795,23 +765,23 @@
     )
     return(cube_tile)
 }
-.local_cube_include_vector_info <- function(cube, vector_items){
-    cube <- slider::slide_dfr(cube, function(tile){
-        item <- dplyr::filter(vector_items, .data[["tile"]] == !!tile$tile)
+.local_cube_include_vector_info <- function(cube, vector_items) {
+    cube <- slider::slide_dfr(cube, function(tile) {
+        item <- dplyr::filter(vector_items, .data[["tile"]] == !!tile[["tile"]])
         vector_info <- tibble::tibble(
-            band = item$band,
-            start_date = item$start_date,
-            end_date = item$end_date,
+            band = item[["band"]],
+            start_date = item[["start_date"]],
+            end_date = item[["end_date"]],
             xres = .xres(.fi(tile)),
             yres = .yres(.fi(tile)),
             xmin = .xmin(.fi(tile)),
             xmax = .xmax(.fi(tile)),
             ymin = .ymin(.fi(tile)),
             ymax = .ymax(.fi(tile)),
-            path = item$path
+            path = item[["path"]]
         )
-        tile$labels <- list(.label_gpkg_file(item$path))
-        tile$vector_info <- list(vector_info)
+        tile[["labels"]] <- list(.label_gpkg_file(item[["path"]]))
+        tile[["vector_info"]] <- list(vector_info)
         return(tile)
     })
 
