@@ -224,10 +224,7 @@ NULL
 
 #' @export
 .tile_update_label.default <- function(tile, labels) {
-    tile <- tibble::as_tibble(tile)
-    tile <- .cube_find_class(tile)
-    tile <- .tile_update_label(tile, labels)
-    return(tile)
+    stop(.conf("messages", ".tile_update_label_default"))
 }
 
 #' @title Get/Set labels
@@ -368,6 +365,27 @@ NULL
     is_complete <- .tile_is_complete(tile)
     return(is_complete)
 }
+#' @title Check if tile's file info is not empty
+#' @name .tile_is_nonempty
+#' @keywords internal
+#' @noRd
+#' @param tile A tile.
+#' @return TRUE/FALSE
+.tile_is_nonempty <- function(tile) {
+    UseMethod(".tile_is_nonempty", tile)
+}
+#' @export
+.tile_is_nonempty.raster_cube <- function(tile) {
+    tile <- .tile(tile)
+    nrow(.fi(tile)) > 0
+}
+#' @export
+.tile_is_nonempty.default <- function(tile) {
+    tile <- tibble::as_tibble(tile)
+    tile <- .cube_find_class(tile)
+    is_nonempty <- .tile_is_nonempty(tile)
+    return(is_nonempty)
+}
 #' @title Get path of first asset from file_info.
 #' @name .tile_path
 #' @keywords internal
@@ -509,13 +527,11 @@ NULL
 }
 #' @export
 `.tile_bands<-.raster_cube` <- function(tile, value) {
+    # set caller to show in errors
+    .check_set_caller(".tile_bands_assign")
     tile <- .tile(tile)
     bands <- .tile_bands(tile)
-    .check_that(
-        length(bands) == length(value),
-        local_msg = paste0("bands must have length ", length(bands)),
-        msg = "invalid band list"
-    )
+    .check_that(length(bands) == length(value))
     rename <- value
     names(rename) <- bands
     .fi(tile) <- .fi_rename_bands(.fi(tile), rename = rename)
@@ -526,8 +542,8 @@ NULL
 #' @name .tile_band_conf
 #' @keywords internal
 #' @noRd
-#' @param tile A tile.
-#' @param band Band character vector.
+#' @param tile   A tile.
+#' @param band   Band character vector.
 #'
 #' @return band_conf or band_cloud_conf
 .tile_band_conf <- function(tile, band) {
@@ -535,10 +551,21 @@ NULL
 }
 #' @export
 .tile_band_conf.eo_cube <- function(tile, band) {
-    .conf_eo_band(
+    band_conf <- .conf_eo_band(
         source = .tile_source(tile), collection = .tile_collection(tile),
         band = band[[1]]
     )
+    if (.has(band_conf))
+        return(band_conf)
+
+    if (band %in% .tile_bands(tile)) {
+        band_path <- .tile_path(tile, band)
+        rast <- terra::rast(band_path)
+        data_type <- terra::datatype(rast)
+        band_conf <- .conf("default_values", data_type)
+        return(band_conf)
+    }
+    return(NULL)
 }
 #' @export
 .tile_band_conf.derived_cube <- function(tile, band) {
@@ -923,13 +950,12 @@ NULL
     is_bit_mask <- .cloud_bit_mask(cloud_conf)
     # Prepare cloud_mask
     # Identify values to be removed
-    if (!is_bit_mask) {
-        values <- values %in% interp_values
-    } else {
+    if (is_bit_mask)
         values <- matrix(bitwAnd(values, sum(2^interp_values)) > 0,
-            nrow = length(values)
+                         nrow = length(values)
         )
-    }
+    else
+        values <- values %in% interp_values
     #
     # Log here
     #
@@ -1050,18 +1076,18 @@ NULL
 #' @name .tile_eo_merge_blocks
 #' @keywords internal
 #' @noRd
-#' @param files files to be merged
-#' @param bands bands to be used in the files
-#' @param base_tile  reference tile used in the operation
-#' @param block_files files associated with the the blocks
-#' @param multicores  multicores for processing
-#' @param update_bbox  should bbox be updated?
+#' @param files         Files to be merged
+#' @param bands         Bands to be merged
+#' @param band_conf     Band confuguration
+#' @param base_tile     Reference tile used in the operation
+#' @param block_files   Files associated with the the blocks
+#' @param multicores    Multicores for processing
+#' @param update_bbox   Should bbox be updated?
 #' @return an EO tile with merged blocks
-.tile_eo_merge_blocks <- function(files, bands, base_tile, block_files,
+.tile_eo_merge_blocks <- function(files, bands, band_conf,
+                                  base_tile, block_files,
                                   multicores, update_bbox) {
     base_tile <- .tile(base_tile)
-    # Get conf band
-    band_conf <- .tile_band_conf(tile = base_tile, band = bands)
     # Create a template raster based on the first image of the tile
     .raster_merge_blocks(
         out_files = files,
@@ -1098,15 +1124,13 @@ NULL
 #' @return a new tile
 .tile_derived_from_file <- function(file, band, base_tile, derived_class,
                                     labels = NULL, update_bbox = FALSE) {
+    # set caller to show in errors
+    .check_set_caller(".tile_derived_from_file")
     if (derived_class %in% c("probs_cube", "variance_cube")) {
         # Open first block file to be merged
         r_obj <- .raster_open_rast(file)
         # Check number of labels is correct
-        .check_that(
-            x = .raster_nlayers(r_obj) == length(labels),
-            local_msg = "number of image layers does not match labels",
-            msg = "invalid 'file' parameter"
-        )
+        .check_that(.raster_nlayers(r_obj) == length(labels))
     }
 
     base_tile <- .tile(base_tile)
@@ -1118,7 +1142,7 @@ NULL
         .xmax(base_tile) <- .raster_xmax(r_obj)
         .ymin(base_tile) <- .raster_ymin(r_obj)
         .ymax(base_tile) <- .raster_ymax(r_obj)
-        .crs(base_tile) <- .raster_crs(r_obj)
+        .crs(base_tile)  <- .raster_crs(r_obj)
     }
     # Update labels before file_info
     .tile_labels(base_tile) <- labels
@@ -1187,15 +1211,13 @@ NULL
 .tile_derived_merge_blocks <- function(file, band, labels, base_tile,
                                        derived_class, block_files, multicores,
                                        update_bbox = FALSE) {
+    # set caller to show in errors
+    .check_set_caller(".tile_derived_merge_blocks")
     if (derived_class %in% c("probs_cube", "variance_cube")) {
         # Open first block file to be merged
         r_obj <- .raster_open_rast(unlist(block_files)[[1]])
         # Check number of labels is correct
-        .check_that(
-            x = .raster_nlayers(r_obj) == length(labels),
-            local_msg = "number of image layers does not match labels",
-            msg = "invalid 'file' parameter"
-        )
+        .check_that(.raster_nlayers(r_obj) == length(labels))
     }
     base_tile <- .tile(base_tile)
     # Get conf band
@@ -1240,7 +1262,8 @@ NULL
 #' @param out_file output file name
 #' @param update_bbox  should bbox be updated?
 #' @return a new tile with files written
-.tile_segment_merge_blocks <- function(block_files, base_tile, band, vector_class,
+.tile_segment_merge_blocks <- function(block_files, base_tile,
+                                       band, vector_class,
                                        out_file, update_bbox = FALSE) {
     base_tile <- .tile(base_tile)
     # Read all blocks file
@@ -1285,7 +1308,7 @@ NULL
 }
 #' @export
 .tile_area_freq.raster_cube <- function(tile) {
-    stop("Cube is not a classified cube")
+    stop(.conf("messages", ".tile_area_freq_raster_cube"))
 }
 #' @export
 .tile_area_freq.default <- function(tile) {
@@ -1309,14 +1332,13 @@ NULL
 #' @return Numeric matrix with raster values for each coordinate.
 #'
 .tile_extract <- function(tile, band, xy) {
+    .check_set_caller(".tile_extract")
     # Create a stack object
     r_obj <- .raster_open_rast(.tile_paths(tile = tile, bands = band))
     # Extract the values
     values <- .raster_extract(r_obj, xy)
     # Is the data valid?
-    if (nrow(values) != nrow(xy)) {
-        stop("number of extracted points differ from requested points")
-    }
+    .check_that(nrow(values) == nrow(xy))
     # Return values
     values
 }
@@ -1328,16 +1350,21 @@ NULL
 #'
 #' @description Given a data cube, retrieve the time series of XY locations
 #'
-#' @param seg_tile_band    Tibble with information on raster and vector files
+#' @param tile ... TODO: document
+#' @param band ...
+#' @param chunk ...
 #'
 #' @return Data.frame with values per polygon.
-#'
-.tile_extract_segments <- function(seg_tile_band) {
+.tile_extract_segments <- function(tile, band, chunk) {
+    tile <- .tile(tile)
+    fi <- .fi(tile)
+    fi <- .fi_filter_bands(fi = fi, bands = band)
+    files <- .fi_paths(fi)
     # Create a SpatRaster object
-    r_obj <- .raster_open_rast(seg_tile_band[["files"]][[1]])
-    names(r_obj) <- paste0(seg_tile_band[["band"]], "-",
-                           seq_len(terra::nlyr(r_obj)))
-    segments <- .vector_read_vec(seg_tile_band[["segs_path"]])
+    r_obj <- .raster_open_rast(files)
+    names(r_obj) <- paste0(band, "-", seq_len(terra::nlyr(r_obj)))
+    # Read the segments
+    segments <- .vector_read_vec(chunk[["segments"]][[1]])
     # Extract the values
     values <- exactextractr::exact_extract(
         x = r_obj,
@@ -1399,4 +1426,96 @@ NULL
     }
     return(invisible(end_time))
 }
-
+#' @title  Return the cell size for the image to be reduced for plotting
+#' @name .tile_overview_size
+#' @keywords internal
+#' @noRd
+#' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
+#'
+#' @param  tile           Tile to be plotted.
+#' @param  max_size       Maximum size of rows or collumns to be shown
+#' @return                Cell size for subimage to be read.
+#'
+#'
+.tile_overview_size <- function(tile, max_size) {
+    # check if the tile is a COG file
+    cog_sizes <- .tile_cog_sizes(tile)
+    if (.has(cog_sizes)) {
+        small_cog_sizes <- purrr::map(cog_sizes, function(cog_size){
+            xsize <- cog_size[["xsize"]]
+            ysize <- cog_size[["ysize"]]
+            if (xsize <= max_size && ysize <= max_size)
+                return(cog_size)
+            else
+                return(NULL)
+        })
+        small_cog_sizes <- purrr::compact(small_cog_sizes)
+        nrows_cog <- small_cog_sizes[[1]][[1]]
+        ncols_cog <- small_cog_sizes[[1]][[2]]
+        return(c(
+            xsize = nrows_cog,
+            ysize = ncols_cog)
+        )
+    } else {
+        # get the maximum number of bytes for the tiles
+        nrows_tile <- max(.tile_nrows(tile))
+        ncols_tile <- max(.tile_ncols(tile))
+        # get the ratio to the max plot size
+        ratio_x <- max(ncols_tile/max_size, 1)
+        ratio_y <- max(nrows_tile/max_size, 1)
+        # if image is smaller than 1000 x 1000, return full size
+        if (ratio_x == 1 && ratio_y == 1) {
+            return(c(
+                xsize = ncols_tile,
+                ysize = nrows_tile
+            ))
+        }
+        # if ratio is greater than 1, get the maximum
+        ratio <- max(ratio_x, ratio_y)
+        # calculate nrows, ncols to be plotted
+        return(c(
+            xsize = floor(ncols_tile/ratio),
+            ysize = floor(nrows_tile/ratio)
+        ))
+    }
+}
+#' @title  Return the size of overviews for COG files
+#' @name .tile_cog_sizes
+#' @keywords internal
+#' @noRd
+#' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
+#'
+#' @param  imag_file       File containing tile to be plotted
+#' @return                 COG size (assumed to be square)
+#'
+#'
+.tile_cog_sizes <- function(tile) {
+    # run gdalinfo on file
+    info <- utils::capture.output(sf::gdal_utils(
+        source = .tile_path(tile),
+        destination = NULL)
+    )
+    info2 <- stringr::str_split(info, pattern = "\n")
+    # capture the line containg overview info
+    over <- unlist(info2[grepl("Overview", info2)])
+    over <- over[!grepl("arbitrary", over)]
+    if (!.has(over))
+        return(NULL)
+    # get the value pairs
+    over_values <- unlist(strsplit(over, split = ":", fixed = TRUE))[2]
+    over_pairs <- unlist(stringr::str_split(over_values, pattern = ","))
+    # extract the COG sizes
+    cog_sizes <- purrr::map(over_pairs, function(op){
+        xsize <- as.numeric(unlist(
+            strsplit(op, split = "x", fixed = TRUE))[[1]]
+        )
+        ysize <- as.numeric(unlist(
+            strsplit(op, split = "x", fixed = TRUE))[[2]]
+        )
+        cog_size <- c(
+            xsize = xsize,
+            ysize = ysize
+        )
+    })
+    return(cog_sizes)
+}
