@@ -89,14 +89,15 @@
 #' }
 #' @export
 sits_accuracy <- function(data, ...) {
-    .check_valid(data)
+    # Set caller to show in errors
+    .check_set_caller("sits_accuracy")
+    .check_na_null_parameter(data)
     UseMethod("sits_accuracy", data)
 }
 #' @rdname sits_accuracy
 #' @export
 sits_accuracy.sits <- function(data, ...) {
-    # Set caller to show in errors
-    .check_set_caller("sits_accuracy.sits")
+    .check_set_caller("sits_accuracy_sits")
     # Require package
     .check_require_packages("caret")
     # Does the input data contain a set of predicted values?
@@ -129,22 +130,14 @@ sits_accuracy.sits <- function(data, ...) {
 #' @rdname sits_accuracy
 #' @export
 sits_accuracy.class_cube <- function(data, ..., validation) {
-    # check the cube is valid
-    .check_cube_files(data)
+    .check_set_caller("sits_accuracy_class_cube")
     # generic function
-    # Is this a CSV file?
+    # Is this a file?
     if (is.character(validation)) {
-        if (tolower(.file_ext(validation)) == "csv") {
-            # Read sample information from CSV file and put it in a tibble
-            validation <- tibble::as_tibble(
-                utils::read.csv(
-                    validation,
-                    stringsAsFactors = FALSE
-                )
-            )
-        } else {
-            stop("Invalid validation parameter for sits_accuracy")
-        }
+        # Is this a valid file?
+        .check_validation_file(validation)
+        # Read sample information from CSV file and put it in a tibble
+        validation <- .csv_get_samples(validation)
     }
     # Precondition - check if validation samples are OK
     validation <- .check_samples(validation)
@@ -157,74 +150,66 @@ sits_accuracy.class_cube <- function(data, ..., validation) {
     pred_ref_lst <- slider::slide(data, function(tile) {
         # Find the labelled band
         labelled_band <- .tile_bands(tile)
-
         # Is the labelled band unique?
-        .check_length(
-            x = labelled_band,
-            len_min = 1,
-            len_max = 1
-        )
-
+        .check_that(length(labelled_band) == 1)
         # get xy in cube projection
         xy_tb <- .proj_from_latlong(
-            longitude = validation$longitude,
-            latitude = validation$latitude,
+            longitude = validation[["longitude"]],
+            latitude = validation[["latitude"]],
             crs = .crs(tile)
         )
-
         # join samples with XY values in a single tibble
         points <- dplyr::bind_cols(validation, xy_tb)
-
         # are there points to be retrieved from the cube?
-        .check_that(
-            x = nrow(points) != 0,
-            msg = paste(
-                "no validation point intersects the map's",
-                "spatiotemporal extent."
-            )
-        )
-
+        .check_that(nrow(points) != 0)
         # Filter the points inside the tile
         points_tile <- dplyr::filter(
             points,
-            .data[["X"]] >= tile$xmin & .data[["X"]] <= tile$xmax &
-                .data[["Y"]] >= tile$ymin & .data[["Y"]] <= tile$ymax
+            .data[["X"]] >= tile[["xmin"]],
+            .data[["X"]] <= tile[["xmax"]],
+            .data[["Y"]] >= tile[["ymin"]],
+            .data[["Y"]] <= tile[["ymax"]]
         )
-
         # No points in the cube? Return an empty list
-        if (nrow(points_tile) < 1) {
+        if (nrow(points_tile) < 1)
             return(NULL)
-        }
 
         # Convert the tibble to a matrix
-        xy <- matrix(c(points_tile$X, points_tile$Y),
-            nrow = nrow(points_tile), ncol = 2
+        xy <- matrix(c(points_tile[["X"]], points_tile[["Y"]]),
+                     nrow = nrow(points_tile),
+                     ncol = 2
         )
         colnames(xy) <- c("X", "Y")
-
         # Extract values from cube
         values <- .tile_extract(
             tile = tile,
             band = labelled_band,
             xy = xy
         )
+        # Transform to vector
+        values <- unlist(values)
+        # Indexes of NA values
+        idx_na <- !is.na(values)
+        # Remove NAs from values
+        values <- values[idx_na]
         # Get the predicted values
-        predicted <- labels_cube[.as_chr(unlist(values))]
-        # Get reference classes
-        reference <- points_tile$label
+        predicted <- labels_cube[.as_chr(values)]
+        # Get reference classes and remove NAs
+        reference <- points_tile[["label"]][idx_na]
         # Does the number of predicted and reference values match?
         .check_pred_ref_match(reference, predicted)
         # Create a tibble to store the results
-        tb <- tibble::tibble(predicted = predicted, reference = reference)
+        tb <- tibble::tibble(
+            predicted = predicted,
+            reference = reference
+        )
         # Return the list
         return(tb)
     })
     # Retrieve predicted and reference vectors for all rows of the cube
     pred_ref <- do.call(rbind, pred_ref_lst)
     # is this data valid?
-    .check_null(pred_ref,
-        msg = "No validation samples inside data cube"
-    )
+    .check_null_parameter(pred_ref)
 
     # Create the error matrix
     error_matrix <- table(
@@ -238,70 +223,46 @@ sits_accuracy.class_cube <- function(data, ..., validation) {
         )
     )
 
-    # Get area for each class for each row of the cube
-    freq_lst <- slider::slide(data, function(tile) {
-        # Get the frequency count and value for each labelled image
-        freq <- .tile_area_freq(tile)
-        # pixel area
-        # convert the area to hectares
-        # assumption: spatial resolution unit is meters
-        area <- freq$count * .tile_xres(tile) * .tile_yres(tile) / 10000
-        # Include class names
-        freq <- dplyr::mutate(freq,
-            area = area,
-            class = labels_cube[.as_chr(freq$value)]
-        )
-        return(freq)
-    })
-    # Get a tibble by binding the row (duplicated labels with different counts)
-    freq <- do.call(rbind, freq_lst)
-    # summarize the counts for each label
-    freq <- freq |>
-        dplyr::filter(!is.na(class)) |>
-        dplyr::group_by(class) |>
-        dplyr::summarise(area = sum(.data[["area"]]))
-
-    # Area is taken as the sum of pixels
-    area <- freq$area
-    # Names of area are the classes
-    names(area) <- freq$class
-    # NAs are set to 0
-    area[is.na(area)] <- 0
-
+    # Get area for each class of the cube
+    class_areas <- .cube_class_areas(cube = data)
     # Compute accuracy metrics
-    acc_area <- .accuracy_area_assess(data, error_matrix, area)
-
+    acc_area <- .accuracy_area_assess(
+        cube = data,
+        error_matrix = error_matrix,
+        area = class_areas
+    )
     class(acc_area) <- c("sits_area_accuracy", class(acc_area))
     return(acc_area)
 }
 #' @rdname sits_accuracy
 #' @export
 sits_accuracy.raster_cube <- function(data, ...) {
-    stop("sits_accuracy needs a classified cube")
+    stop(.conf("messages", "sits_accuracy_raster_cube"))
 }
 #' @rdname sits_accuracy
 #' @export
 sits_accuracy.derived_cube <- function(data, ...) {
-    stop("sits_accuracy needs a classified cube")
+    stop(.conf("messages", "sits_accuracy_raster_cube"))
 }
 #' @rdname sits_accuracy
 #' @export
-sits_accuracy.tbl_df <- function(data,...) {
+sits_accuracy.tbl_df <- function(data, ...) {
     data <- tibble::as_tibble(data)
     if (all(.conf("sits_cube_cols") %in% colnames(data))) {
         data <- .cube_find_class(data)
     } else if (all(.conf("sits_tibble_cols") %in% colnames(data))) {
         class(data) <- c("sits", class(data))
-    } else
-        stop("Input should be a sits tibble or a data cube")
+    } else {
+        stop(.conf("messages", "sits_accuracy_tbl_df"))
+    }
     acc <- sits_accuracy(data, ...)
     return(acc)
 }
 #' @rdname sits_accuracy
 #' @export
-sits_accuracy.default <- function(data,...) {
+sits_accuracy.default <- function(data, ...) {
     data <- tibble::as_tibble(data)
-    acc <- sits_accuracy(data,...)
+    acc <- sits_accuracy(data, ...)
     return(acc)
 }
 #' @title Print accuracy summary
@@ -323,24 +284,21 @@ sits_accuracy_summary <- function(x, digits = NULL) {
     # default value for digits
     digits <- .default(digits, max(3, getOption("digits") - 3))
 
-    if ("sits_area_accuracy" %in% class(x)) {
+    if (inherits(x, "sits_area_accuracy")) {
         print.sits_area_accuracy(x)
         return(invisible(TRUE))
     }
     # is data of class sits_accuracy
     .check_is_sits_accuracy(x)
     # round the data to the significant digits
-    overall <- round(x$overall, digits = digits)
+    overall <- round(x[["overall"]], digits = digits)
 
-    accuracy_ci <- paste(
-        "(", paste(overall[c("AccuracyLower", "AccuracyUpper")],
-            collapse = ", "
-        ), ")",
-        sep = ""
+    accuracy_ci <- paste0(
+        "(", toString(overall[c("AccuracyLower", "AccuracyUpper")]), ")"
     )
     overall_text <- c(
-        paste(overall["Accuracy"]), accuracy_ci,
-        paste(overall["Kappa"])
+        paste(overall[["Accuracy"]]), accuracy_ci,
+        paste(overall[["Kappa"]])
     )
     overall_names <- c("Accuracy", "95% CI", "Kappa")
 
@@ -376,26 +334,24 @@ print.sits_accuracy <- function(x, ..., digits = NULL) {
     # rename confusion matrix names
     names(x) <- c("positive", "table", "overall", "by_class", "mode", "dots")
     cat("Confusion Matrix and Statistics\n\n")
-    print(x$table)
+    print(x[["table"]])
 
     # Round the data to the significant digits
-    overall <- round(x$overall, digits = digits)
+    overall <- round(x[["overall"]], digits = digits)
     # Format accuracy
     accuracy_ci <- paste(
-        "(", paste(overall[c("AccuracyLower", "AccuracyUpper")],
-            collapse = ", "
-        ), ")",
-        sep = ""
+        "(",
+        paste(overall[c("AccuracyLower", "AccuracyUpper")], collapse = ", "),
+        ")", sep = ""
     )
-
     overall_text <- c(
-        paste(overall["Accuracy"]), accuracy_ci, "",
-        paste(overall["Kappa"])
+        paste(overall[["Accuracy"]]), accuracy_ci, "",
+        paste(overall[["Kappa"]])
     )
 
     overall_names <- c("Accuracy", "95% CI", "", "Kappa")
 
-    if (dim(x$table)[1] > 2) {
+    if (dim(x[["table"]])[[1]] > 2) {
         # Multiclass case
         # Names in caret are different from usual names in Earth observation
         cat("\nOverall Statistics\n")
@@ -420,8 +376,10 @@ print.sits_accuracy <- function(x, ..., digits = NULL) {
             ),
             collapse = "|"
         )
-        x$by_class <- x$by_class[, grepl(pattern_format, colnames(x$by_class))]
-        measures <- t(x$by_class)
+        x[["by_class"]] <- x[["by_class"]][,
+                                grepl(pattern_format, colnames(x[["by_class"]]))
+        ]
+        measures <- t(x[["by_class"]])
         rownames(measures) <- c(
             "Prod Acc (Sensitivity)", "Specificity",
             "User Acc (Pos Pred Value)", "Neg Pred Value", "F1 score"
@@ -439,26 +397,28 @@ print.sits_accuracy <- function(x, ..., digits = NULL) {
             ),
             collapse = "|"
         )
-        x$by_class <- x$by_class[grepl(pattern_format, names(x$by_class))]
+        x[["by_class"]] <- x[["by_class"]][
+            grepl(pattern_format, names(x[["by_class"]]))
+        ]
         # Names of the two classes
-        names_classes <- row.names(x$table)
+        names_classes <- row.names(x[["table"]])
         # First class is called the "positive" class by caret
-        c1 <- x$positive
+        c1 <- x[["positive"]]
         # Second class
-        c2 <- names_classes[!(names_classes == x$positive)]
+        c2 <- names_classes[!(names_classes == x[["positive"]])]
         # Values of UA and PA for the two classes
         pa1 <- paste("Prod Acc ", c1)
         pa2 <- paste("Prod Acc ", c2)
         ua1 <- paste("User Acc ", c1)
         ua2 <- paste("User Acc ", c2)
-        names(x$by_class) <- c(pa1, pa2, ua1, ua2)
+        names(x[["by_class"]]) <- c(pa1, pa2, ua1, ua2)
 
         overall_text <- c(
             overall_text,
             "",
-            format(x$by_class, digits = digits)
+            format(x[["by_class"]], digits = digits)
         )
-        overall_names <- c(overall_names, "", names(x$by_class))
+        overall_names <- c(overall_names, "", names(x[["by_class"]]))
         overall_names <- ifelse(overall_names == "", "",
             paste(overall_names, ":")
         )
@@ -489,13 +449,13 @@ print.sits_accuracy <- function(x, ..., digits = NULL) {
 #' @export
 print.sits_area_accuracy <- function(x, ..., digits = 2) {
     # round the data to the significant digits
-    overall <- round(x$accuracy$overall, digits = digits)
+    overall <- round(x[["accuracy"]][["overall"]], digits = digits)
 
-    cat("Area Weigthed Statistics\n")
+    cat("Area Weighted Statistics\n")
     cat(paste0("Overall Accuracy = ", overall, "\n"))
 
-    acc_user <- round(x$accuracy$user, digits = digits)
-    acc_prod <- round(x$accuracy$producer, digits = digits)
+    acc_user <- round(x[["accuracy"]][["user"]], digits = digits)
+    acc_prod <- round(x[["accuracy"]][["producer"]], digits = digits)
 
     # Print accuracy values
     tb <- t(dplyr::bind_rows(acc_user, acc_prod))
@@ -505,9 +465,9 @@ print.sits_area_accuracy <- function(x, ..., digits = 2) {
 
     print(tb)
 
-    area_pix <- round(x$area_pixels, digits = digits)
-    area_adj <- round(x$error_ajusted_area, digits = digits)
-    conf_int <- round(x$conf_interval, digits = digits)
+    area_pix <- round(x[["area_pixels"]], digits = digits)
+    area_adj <- round(x[["error_ajusted_area"]], digits = digits)
+    conf_int <- round(x[["conf_interval"]], digits = digits)
 
     tb1 <- t(dplyr::bind_rows(area_pix, area_adj, conf_int))
     colnames(tb1) <- c(
