@@ -61,6 +61,7 @@ sits_cluster_dendro <- function(samples,
                                 linkage = "ward.D2",
                                 k = NULL,
                                 palette = "RdYlGn") {
+    .check_set_caller("sits_cluster_dendro")
     # needs package dtwclust
     .check_require_packages("dtwclust")
     # verify if data is OK
@@ -69,19 +70,13 @@ sits_cluster_dendro <- function(samples,
     bands <- .default(bands, sits_bands(samples))
     bands <- .tibble_bands_check(samples, bands)
     # check k (number of clusters)
-    if (!purrr::is_null(k)) {
-        .check_num_parameter(k, min = 2,  max = 200)
+    if (.has(k)) {
+        .check_int_parameter(k, min = 2,  max = 200)
     }
     # check distance method
-    .check_that(
-        dist_method %in% .conf("dendro_dist_method"),
-        msg = "Invalid distance method for dendrogram calculation"
-    )
+    .check_dist_method(dist_method)
     # check linkage
-    .check_that(
-        linkage %in% .conf("dendro_linkage"),
-        msg = "Invalid linkage method for dendrogram calculation"
-    )
+    .check_linkage_method(linkage)
     # check palette
     .check_palette(palette)
      UseMethod("sits_cluster_dendro", samples)
@@ -105,24 +100,24 @@ sits_cluster_dendro.sits <- function(samples,
 
     # find the best cut for the dendrogram
     best_cut <- .cluster_dendro_bestcut(samples, cluster)
-    message(paste0("best number of clusters = ", best_cut["k"]))
-    message(paste0(
-        "best height for cutting the dendrogram = ",
-        best_cut["height"]
-    ))
+    message(.conf("messages", "sits_cluster_dendro_best_number"),
+            best_cut[["k"]]
+    )
+    message(.conf("messages", "sits_cluster_dendro_best_height"),
+            best_cut[["height"]]
+    )
     # cut the tree (user-defined value overrides default)
-    k <- .default(k, best_cut["k"])
-    if (k != best_cut["k"]) {
-        message(paste0("Caveat: desired number of clusters (", k, ")
-                            overrides best value"))
-        best_cut["k"] <- k
-        best_cut["height"] <-
-            c(0, cluster$height)[length(cluster$height) - k + 2]
+    k <- .default(k, best_cut[["k"]])
+    if (k != best_cut[["k"]]) {
+        message(.conf("messages", "sits_cluster_dendro_best_cut"))
+        best_cut[["k"]] <- k
+        best_cut[["height"]] <-
+            c(0, cluster[["height"]])[length(cluster[["height"]]) - k + 2]
     }
-    samples$cluster <- stats::cutree(
+    samples[["cluster"]] <- stats::cutree(
         cluster,
-        best_cut["k"],
-        best_cut["height"]
+        best_cut[["k"]],
+        best_cut[["height"]]
     )
     # change the class
     class(samples) <- c("sits_cluster", class(samples))
@@ -130,27 +125,23 @@ sits_cluster_dendro.sits <- function(samples,
     plot(
         x = samples,
         cluster = cluster,
-        cutree_height = best_cut["height"],
+        cutree_height = best_cut[["height"]],
         palette = palette
     )
     return(samples)
 }
 #' @rdname sits_cluster_dendro
 #' @export
-sits_cluster_dendro.tbl_df <- function(samples, ...) {
+sits_cluster_dendro.default <- function(samples, ...) {
     samples <- tibble::as_tibble(samples)
     if (all(.conf("sits_tibble_cols") %in% colnames(samples))) {
         class(samples) <- c("sits", class(samples))
-    } else
-        stop("Input should be a sits tibble")
+    } else {
+        stop(.conf("messages", "sits_cluster_dendro_default"))
+    }
     samples <- sits_cluster_dendro(samples, ...)
     return(samples)
 }
-#' @rdname sits_cluster_dendro
-#' @export
-sits_cluster_dendro.default <- function(samples, ...) {
-    stop("Input samples should be of class sits")
-}
 #'
 #' @title Show label frequency in each cluster produced by dendrogram analysis
 #' @name sits_cluster_frequency
@@ -170,11 +161,10 @@ sits_cluster_dendro.default <- function(samples, ...) {
 sits_cluster_frequency <- function(samples) {
     # set caller to show in errors
     .check_set_caller("sits_cluster_frequency")
-
     # is the input data the result of a cluster function?
     .check_samples_cluster(samples)
     # compute frequency table (matrix)
-    result <- table(samples$label, samples$cluster)
+    result <- table(samples[["label"]], samples[["cluster"]])
     # compute total row and col
     result <- stats::addmargins(result,
         FUN = list(Total = sum),
@@ -211,11 +201,11 @@ sits_cluster_clean <- function(samples) {
     # is the input data the result of a cluster function?
     .check_samples_cluster(samples)
     # compute frequency table (matrix)
-    result <- table(samples$label, samples$cluster)
+    result <- table(samples[["label"]], samples[["cluster"]])
     # list of number of clusters
-    num_cls <- unique(samples$cluster)
+    num_cls <- unique(samples[["cluster"]])
     # get the labels of the data
-    lbs <- unique(samples$label)
+    lbs <- unique(samples[["label"]])
     # for each cluster, get the label with the maximum number of samples
     lbs_max <- lbs[as.vector(apply(result, 2, which.max))]
     # compute the resulting table
@@ -224,9 +214,9 @@ sits_cluster_clean <- function(samples) {
         function(lb, cl) {
             partial <- dplyr::filter(
                 samples,
-                .data[["label"]] == lb &
-                    .data[["cluster"]] == cl
-            )
+                .data[["label"]] == lb,
+                .data[["cluster"]] == cl
+             )
             return(partial)
         }
     )
