@@ -9,11 +9,6 @@
 #'
 #' @param  cube        Classified image data cube.
 #' @param  ...         Other parameters for specific functions.
-#' @param  clean       A logical value to apply a modal function to clean up
-#'                     possible noisy pixels keeping the most frequently
-#'                     values within the neighborhood. Default is TRUE.
-#' @param window_size  An odd integer representing the size of the
-#'                     sliding window of the modal function (min = 1, max = 15).
 #' @param  multicores  Number of workers to label the classification in
 #'                     parallel.
 #' @param  memsize     maximum overall memory (in GB) to label the
@@ -58,13 +53,12 @@
 #' }
 #' @export
 sits_label_classification <- function(cube,
-                                      clean = TRUE,
-                                      window_size = 3L,
-                                      memsize = 4,
-                                      multicores = 2,
+                                      memsize = 4L,
+                                      multicores = 2L,
                                       output_dir,
                                       version = "v1",
                                       progress = TRUE) {
+    .check_set_caller("sits_label_classification")
     # Dispatch
     UseMethod("sits_label_classification", cube)
 }
@@ -72,19 +66,15 @@ sits_label_classification <- function(cube,
 #' @rdname sits_label_classification
 #' @export
 sits_label_classification.probs_cube <- function(cube, ...,
-                                                 clean = TRUE,
-                                                 window_size = 3L,
                                                  memsize = 4L,
                                                  multicores = 2L,
                                                  output_dir,
                                                  version = "v1",
                                                  progress = TRUE) {
     # Pre-conditions - Check parameters
-    .check_cube_files(cube)
-    .check_lgl_parameter(clean)
-    .check_window_size(window_size = window_size, min = 3, max = 15)
-    .check_memsize(memsize, min = 1, max = 16384)
-    .check_multicores(multicores, min = 1, max = 2048)
+    .check_raster_cube_files(cube)
+    .check_num_parameter(memsize, min = 1, max = 16384)
+    .check_num_parameter(multicores, min = 1, max = 2048)
     .check_output_dir(output_dir)
     version <- .check_version(version)
     # version is case-insensitive in sits
@@ -92,10 +82,6 @@ sits_label_classification.probs_cube <- function(cube, ...,
 
     # Get block size
     block <- .raster_file_blocksize(.raster_open_rast(.tile_path(cube)))
-    # Get image size
-    image_size <- .raster_size(.raster_open_rast(.tile_path(cube)))
-    # Overlapping pixels
-    overlap <- ceiling(window_size / 2) - 1
     # Check minimum memory needed to process one block
     job_memsize <- .jobs_memsize(
         job_size = .block_size(block = block, overlap = 0),
@@ -120,24 +106,6 @@ sits_label_classification.probs_cube <- function(cube, ...,
     label_fn <- .label_fn_majority()
     # Process each tile sequentially
     class_cube <- .cube_foreach_tile(cube, function(tile) {
-        # Output file
-        out_file <- .file_derived_name(
-            tile = tile, band = "class", version = version,
-            output_dir = output_dir
-        )
-        # Resume feature
-        if (file.exists(out_file)) {
-            .check_recovery(tile[["tile"]])
-            class_tile <- .tile_derived_from_file(
-                file = out_file,
-                band = "class",
-                base_tile = tile,
-                derived_class = "class_cube",
-                labels = .tile_labels(tile),
-                update_bbox = FALSE
-            )
-            return(class_tile)
-        }
         # Label the data
         class_tile <- .label_tile(
             tile = tile,
@@ -147,18 +115,6 @@ sits_label_classification.probs_cube <- function(cube, ...,
             version = version,
             progress = progress
         )
-        if (clean) {
-            # Apply clean in data
-            class_tile <- .clean_tile(
-                tile = class_tile,
-                block = image_size,
-                band = "class",
-                window_size = window_size,
-                overlap = overlap,
-                output_dir = output_dir,
-                version = version
-            )
-        }
         return(class_tile)
     })
     return(class_cube)
@@ -171,7 +127,7 @@ sits_label_classification.probs_vector_cube <- function(cube, ...,
                                                         version = "v1",
                                                         progress = TRUE) {
     # Pre-conditions - Check parameters
-    .check_cube_files(cube)
+    .check_raster_cube_files(cube)
     .check_output_dir(output_dir)
     version <- .check_version(version)
     # version is case-insensitive in sits
@@ -194,31 +150,23 @@ sits_label_classification.probs_vector_cube <- function(cube, ...,
 #' @rdname sits_label_classification
 #' @export
 sits_label_classification.raster_cube <- function(cube, ...) {
-    stop("Input should be a classified cube")
-    return(cube)
+    stop(.conf("messages", "sits_label_classification"))
 }
 
 #' @rdname sits_label_classification
 #' @export
 sits_label_classification.derived_cube <- function(cube, ...) {
-    stop("Input should be a classified cube")
-    return(cube)
-}
-
-#' @rdname sits_label_classification
-#' @export
-sits_label_classification.tbl_df <- function(cube, ...){
-    cube <- tibble::as_tibble(cube)
-    if (all(.conf("sits_cube_cols") %in% colnames(cube))) {
-        cube <- .cube_find_class(cube)
-    } else
-        stop("Input should be a classified cube")
-    class_cube <- sits_label_classification(cube, ...)
-    return(class_cube)
+    stop(.conf("messages", "sits_label_classification"))
 }
 
 #' @rdname sits_label_classification
 #' @export
 sits_label_classification.default <- function(cube, ...) {
-    stop("Input should be a classified cube")
+    cube <- tibble::as_tibble(cube)
+    if (all(.conf("sits_cube_cols") %in% colnames(cube)))
+        cube <- .cube_find_class(cube)
+    else
+        stop(.conf("messages", "sits_label_classification"))
+    class_cube <- sits_label_classification(cube, ...)
+    return(class_cube)
 }
