@@ -30,7 +30,7 @@
 #'     # Retrieve the samples for Mato Grosso
 #'     # train a random forest model
 #'     rf_model <- sits_train(samples_modis_ndvi,
-#'         ml_method = sits_rfor(mtry = 20)
+#'         ml_method = sits_rfor
 #'     )
 #'     # classify the point
 #'     point_ndvi <- sits_select(point_mt_6bands, bands = "NDVI")
@@ -43,25 +43,28 @@
 #' @export
 #'
 sits_rfor <- function(samples = NULL, num_trees = 100, mtry = NULL, ...) {
+    .check_set_caller("sits_rfor")
     # Function that trains a random forest model
     train_fun <- function(samples) {
         # Verifies if 'randomForest' package is installed
         .check_require_packages("randomForest")
         # Checks 'num_trees'
-        .check_int_parameter(num_trees)
+        .check_int_parameter(num_trees, min = 20)
         # Get labels (used later to ensure column order in result matrix)
         labels <- .samples_labels(samples)
         # Get predictors features
         train_samples <- .predictors(samples)
         # Post condition: is predictor data valid?
         .check_predictors(pred = train_samples, samples = samples)
-
+        # determine number of random forest
+        n_features <- ncol(train_samples) - 2
         # Apply the 'mtry' default value of 'randomForest' package
-        if (purrr::is_null(mtry)) {
-            n_features <- ncol(train_samples) - 2
-            mtry <- floor(sqrt(n_features))
+        if (.has(mtry)) {
             # Checks 'mtry'
             .check_int_parameter(mtry, min = 1, max = n_features)
+        } else {
+            # set the default values of `mtry`
+            mtry <- floor(sqrt(n_features))
         }
         # Train a random forest model
         model <- randomForest::randomForest(
@@ -76,13 +79,13 @@ sits_rfor <- function(samples = NULL, num_trees = 100, mtry = NULL, ...) {
             # Verifies if randomForest package is installed
             .check_require_packages("randomForest")
             # Used to check values (below)
-            input_pixels <- nrow(values)
+            n_input_pixels <- nrow(values)
             # Do classification
             values <- stats::predict(
                 object = model, newdata = values, type = "prob"
             )
             # Are the results consistent with the data input?
-            .check_processed_values(values, input_pixels)
+            .check_processed_values(values, n_input_pixels)
             # Reorder matrix columns if needed
             if (any(labels != colnames(values))) {
                 values <- values[, labels]
@@ -159,6 +162,7 @@ sits_svm <- function(samples = NULL, formula = sits_formula_linear(),
                      scale = FALSE, cachesize = 1000, kernel = "radial",
                      degree = 3, coef0 = 0, cost = 10, tolerance = 0.001,
                      epsilon = 0.1, cross = 10, ...) {
+    .check_set_caller("sits_svm")
     # Function that trains a support vector machine model
     train_fun <- function(samples) {
         # Verifies if e1071 package is installed
@@ -189,7 +193,7 @@ sits_svm <- function(samples = NULL, formula = sits_formula_linear(),
             # Verifies if e1071 package is installed
             .check_require_packages("e1071")
             # Used to check values (below)
-            input_pixels <- nrow(values)
+            n_input_pixels <- nrow(values)
             # Performs data normalization
             values <- .pred_normalize(pred = values, stats = ml_stats)
             # Do classification
@@ -199,7 +203,7 @@ sits_svm <- function(samples = NULL, formula = sits_formula_linear(),
             # Get the predicted probabilities
             values <- attr(values, "probabilities")
             # Are the results consistent with the data input?
-            .check_processed_values(values, input_pixels)
+            .check_processed_values(values, n_input_pixels)
             # Reorder matrix columns if needed
             if (any(labels != colnames(values))) {
                 values <- values[, labels]
@@ -255,6 +259,7 @@ sits_svm <- function(samples = NULL, formula = sits_formula_linear(),
 #' @param nfold            Number of the subsamples for the cross-validation.
 #' @param nrounds          Number of rounds to iterate the cross-validation
 #'                         (default: 100)
+#' @param nthread          Number of threads (default = 6)
 #' @param early_stopping_rounds Training with a validation set will stop
 #'                         if the performance doesn't improve for k rounds.
 #' @param verbose          Print information on statistics during the process
@@ -284,7 +289,9 @@ sits_xgboost <- function(samples = NULL, learning_rate = 0.15,
                          min_split_loss = 1, max_depth = 5,
                          min_child_weight = 1, max_delta_step = 1,
                          subsample = 0.8, nfold = 5, nrounds = 100,
+                         nthread = 6,
                          early_stopping_rounds = 20, verbose = FALSE) {
+    .check_set_caller("sits_xgboost")
     # Function that trains a xgb model
     train_fun <- function(samples) {
         # verifies if xgboost package is installed
@@ -307,29 +314,37 @@ sits_xgboost <- function(samples = NULL, learning_rate = 0.15,
             eval_metric = "mlogloss", eta = learning_rate,
             gamma = min_split_loss, max_depth = max_depth,
             min_child_weight = min_child_weight,
-            max_delta_step = max_delta_step, subsample = subsample
+            max_delta_step = max_delta_step, subsample = subsample,
+            nthread = nthread
         )
-        # Train a xgboost model
-        model <- xgboost::xgboost(
+        if (verbose)
+            verbose <-  1
+        else
+            verbose <-  0
+        # transform predictors in a xgb.DMatrix
+        xgb_matrix <- xgboost::xgb.DMatrix(
             data = as.matrix(.pred_features(train_samples)),
-            label = references, num_class = length(labels), params = params,
-            nrounds = nrounds, verbose = FALSE
+            label = references)
+        # train the model
+        model <- xgboost::xgb.train(xgb_matrix,
+            num_class = length(labels), params = params,
+            nrounds = nrounds, verbose = verbose
         )
         # Get best ntreelimit
-        ntreelimit <- model$best_ntreelimit
+        ntreelimit <- model[["best_ntreelimit"]]
         # Function that predicts labels of input values
         predict_fun <- function(values) {
             # Verifies if xgboost package is installed
             .check_require_packages("xgboost")
             # Used to check values (below)
-            input_pixels <- nrow(values)
+            n_input_pixels <- nrow(values)
             # Do classification
             values <- stats::predict(
                 object = model, as.matrix(values), ntreelimit = ntreelimit,
                 reshape = TRUE
             )
             # Are the results consistent with the data input?
-            .check_processed_values(values, input_pixels)
+            .check_processed_values(values, n_input_pixels)
             # Update the columns names to labels
             colnames(values) <- labels
             return(values)
@@ -386,22 +401,18 @@ sits_formula_logref <- function(predictors_index = -2:0) {
     .check_set_caller("sits_formula_logref")
 
     # store configuration information about model formula
-    sits_env$model_formula <- "log"
+    sits_env[["model_formula"]] <- "log"
 
     # this function returns a formula like
     # 'factor(reference~log(f1)+log(f2)+...+log(fn)' where f1, f2, ..., fn are
     # the predictor fields given by the predictor index.
     result_fun <- function(tb) {
-        .check_that(
-            x = nrow(tb) > 0,
-            msg = "invalid data"
-        )
+        .check_that(nrow(tb) > 0)
         n_rows_tb <- nrow(tb)
 
         # if no predictors_index are given, assume all tb's fields are used
-        if (purrr::is_null(predictors_index)) {
+        if (!.has(predictors_index))
             predictors_index <- 1:n_rows_tb
-        }
 
         # get predictors names
         categories <- names(tb)[c(predictors_index)]
@@ -456,21 +467,17 @@ sits_formula_linear <- function(predictors_index = -2:0) {
     .check_set_caller("sits_formula_linear")
 
     # store configuration information about model formula
-    sits_env$model_formula <- "linear"
+    sits_env[["model_formula"]] <- "linear"
 
     # this function returns a formula
     # 'factor(reference~log(f1)+log(f2)+...+log(fn)' where f1, f2, ..., fn are
     #  the predictor fields.
     result_fun <- function(tb) {
-        .check_that(
-            x = nrow(tb) > 0,
-            msg = "invalid data"
-        )
+        .check_that(nrow(tb) > 0)
         n_rows_tb <- nrow(tb)
         # if no predictors_index are given, assume that all fields are used
-        if (purrr::is_null(predictors_index)) {
+        if (!.has(predictors_index))
             predictors_index <- 1:n_rows_tb
-        }
 
         # get predictors names
         categories <- names(tb)[c(predictors_index)]
