@@ -99,10 +99,12 @@ sits_mixture_model <- function(data, endmembers, ...,
                                rmse_band = TRUE,
                                multicores = 2,
                                progress = TRUE) {
+    # set caller for error msg
+    .check_set_caller("sits_mixture_model")
     # Pre-conditions
     .check_endmembers_parameter(endmembers)
     .check_lgl_parameter(rmse_band)
-    .check_multicores(multicores, min = 1, max = 2048)
+    .check_int_parameter(multicores, min = 1, max = 2048)
     .check_progress(progress)
     UseMethod("sits_mixture_model", data)
 }
@@ -161,9 +163,9 @@ sits_mixture_model.raster_cube <- function(data, endmembers, ...,
                                            progress = TRUE) {
     # Pre-conditions
     .check_is_raster_cube(data)
-    .check_memsize(memsize, min = 1, max = 16384)
+    .check_int_parameter(memsize, min = 1, max = 16384)
     .check_output_dir(output_dir)
-    .check_lgl_type(progress)
+    .check_lgl_parameter(progress)
     # Transform endmembers to tibble
     em <- .endmembers_as_tbl(endmembers)
     # Check endmember format
@@ -174,7 +176,7 @@ sits_mixture_model.raster_cube <- function(data, endmembers, ...,
     # is added as a band
     data <- .cube_filter_bands(cube = data, bands = bands)
     # Check if cube is regular
-    .check_is_regular(data)
+    .check_that(.cube_is_regular(data))
     # Pre-condition
     .check_endmembers_bands(
         em = em,
@@ -201,6 +203,9 @@ sits_mixture_model.raster_cube <- function(data, endmembers, ...,
         image_size = .tile_size(.tile(data)), memsize = memsize,
         multicores = multicores
     )
+    # Terra requires at least two pixels to recognize an extent as valid
+    # polygon and not a line or point
+    block <- .block_regulate_size(block)
     # Prepare parallelization
     .parallel_start(workers = multicores, output_dir = output_dir)
     on.exit(.parallel_stop(), add = TRUE)
@@ -222,7 +227,9 @@ sits_mixture_model.raster_cube <- function(data, endmembers, ...,
         return(output_feature)
     }, progress = progress)
     # Join output features as a cube and return it
-    cube <- .cube_merge_tiles(dplyr::bind_rows(list(features_cube, features_fracs)))
+    cube <- .cube_merge_tiles(dplyr::bind_rows(list(features_cube,
+                                                    features_fracs))
+    )
     # Join groups samples as a sits tibble and return it
     class(cube) <- c("raster_cube", class(cube))
     return(cube)
@@ -230,24 +237,25 @@ sits_mixture_model.raster_cube <- function(data, endmembers, ...,
 #' @rdname sits_mixture_model
 #' @export
 sits_mixture_model.derived_cube <- function(data, endmembers, ...) {
-    stop("Input should not be a cube that has been classified")
-    return(data)
+    stop(.conf("messages", "sits_mixture_model_derived_cube"))
 }
 #' @rdname sits_mixture_model
 #' @export
 sits_mixture_model.tbl_df <- function(data, endmembers, ...) {
     data <- tibble::as_tibble(data)
-    if (all(.conf("sits_cube_cols") %in% colnames(data))) {
+    if (all(.conf("sits_cube_cols") %in% colnames(data)))
         data <- .cube_find_class(data)
-    } else if (all(.conf("sits_tibble_cols") %in% colnames(data))) {
+    else if (all(.conf("sits_tibble_cols") %in% colnames(data)))
         class(data) <- c("sits", class(data))
-    } else
-        stop("Input should be a sits tibble or a data cube")
+    else
+        stop(.conf("messages", "sits_mixture_model_derived_cube"))
     data <- sits_mixture_model(data, endmembers, ...)
     return(data)
 }
 #' @rdname sits_mixture_model
 #' @export
-sits_mixture_model.default <- function(data, endmembers, ...){
-    stop("Input should be an object of class cube or class sits")
+sits_mixture_model.default <- function(data, endmembers, ...) {
+    data <- tibble::as_tibble(data)
+    data <- sits_mixture_model(data, endmembers, ...)
+    return(data)
 }
