@@ -122,6 +122,8 @@ sits_resnet <- function(samples = NULL,
                         patience = 20,
                         min_delta = 0.01,
                         verbose = FALSE) {
+    # set caller for error msg
+    .check_set_caller("sits_resnet")
     # Function that trains a torch model based on samples
     train_fun <- function(samples) {
         # Avoid add a global variable for 'self'
@@ -130,29 +132,29 @@ sits_resnet <- function(samples = NULL,
         .check_require_packages(c("torch", "luz"))
         # Pre-conditions:
         .check_samples_train(samples)
-        .check_int_parameter(param = blocks, min = 1, len_max = 2^31 - 1)
-        .check_int_parameter(
-            param = kernels, min = 1, len_min = length(blocks),
+        .check_int_parameter(blocks)
+        .check_int_parameter(kernels,
+            min = 1,
+            len_min = length(blocks),
             len_max = length(blocks)
         )
         .check_int_parameter(epochs)
         .check_int_parameter(batch_size)
-        .check_null(optimizer, msg = "invalid 'optimizer' parameter")
+        .check_null_parameter(optimizer)
         # Check validation_split parameter if samples_validation is not passed
-        if (is.null(samples_validation)) {
-            .check_num_parameter(
-                param = validation_split, exclusive_min = 0, max = 0.5
-            )
-        }
+        if (!.has(samples_validation))
+            .check_num_parameter(validation_split, exclusive_min = 0, max = 0.5)
         # Check opt_hparams
         # Get parameters list and remove the 'param' parameter
         optim_params_function <- formals(optimizer)[-1]
         if (!is.null(opt_hparams)) {
-            .check_lst(opt_hparams, msg = "invalid 'opt_hparams' parameter")
+            .check_lst_parameter(opt_hparams,
+                                 msg = .conf("messages", ".check_opt_hparams")
+            )
             .check_chr_within(
                 x = names(opt_hparams),
                 within = names(optim_params_function),
-                msg = "invalid hyperparameters provided in optimizer"
+                msg = .conf("messages", ".check_opt_hparams")
             )
             optim_params_function <- utils::modifyList(
                 x = optim_params_function, val = opt_hparams
@@ -160,10 +162,10 @@ sits_resnet <- function(samples = NULL,
         }
         # Other pre-conditions:
         .check_int_parameter(lr_decay_epochs)
-        .check_num_parameter(param = lr_decay_rate, exclusive_min = 0, max = 1)
+        .check_num_parameter(lr_decay_rate, exclusive_min = 0, max = 1)
         .check_int_parameter(patience)
-        .check_num_parameter(param = min_delta, min = 0)
-        .check_lgl(verbose)
+        .check_num_parameter(min_delta, min = 0)
+        .check_lgl_parameter(verbose)
 
         # Samples labels
         labels <- sits_labels(samples)
@@ -195,7 +197,7 @@ sits_resnet <- function(samples = NULL,
                 timeline = timeline, bands = bands
             )
             # Test samples are extracted from validation data
-            test_samples <- .predictors(samples)
+            test_samples <- .predictors(samples_validation)
             test_samples <- .pred_normalize(
                 pred = test_samples, stats = ml_stats
             )
@@ -206,7 +208,8 @@ sits_resnet <- function(samples = NULL,
                 pred = train_samples, frac = validation_split
             )
             # Remove the lines used for validation
-            sel <- !train_samples$sample_id %in% test_samples$sample_id
+            sel <- !train_samples[["sample_id"]] %in%
+                test_samples[["sample_id"]]
             train_samples <- train_samples[sel, ]
         }
         n_samples_train <- nrow(train_samples)
@@ -242,21 +245,21 @@ sits_resnet <- function(samples = NULL,
                 self$conv_block1 <- .torch_batch_conv1D_batch_norm_relu(
                     input_dim   = in_channels,
                     output_dim  = out_channels,
-                    kernel_size = kernels[1],
+                    kernel_size = kernels[[1]],
                     padding     = "same"
                 )
                 # create second convolution block
                 self$conv_block2 <- .torch_conv1D_batch_norm_relu(
                     input_dim   = out_channels,
                     output_dim  = out_channels,
-                    kernel_size = kernels[2],
+                    kernel_size = kernels[[2]],
                     padding     = "same"
                 )
                 # create third convolution block
                 self$conv_block3 <- .torch_conv1D_batch_norm(
                     input_dim   = out_channels,
                     output_dim  = out_channels,
-                    kernel_size = kernels[3],
+                    kernel_size = kernels[[3]],
                     padding     = "same"
                 )
                 # create shortcut
@@ -283,16 +286,25 @@ sits_resnet <- function(samples = NULL,
         resnet_model <- torch::nn_module(
             classname = "model_resnet",
             initialize = function(n_bands, n_times, n_labels, blocks, kernels) {
-                self$res_block1 <- resnet_block(n_bands, blocks[1], kernels)
-                self$res_block2 <- resnet_block(blocks[1], blocks[2], kernels)
-                self$res_block3 <- resnet_block(blocks[2], blocks[3], kernels)
+                self$res_block1 <- resnet_block(n_bands,
+                                                blocks[[1]],
+                                                kernels
+                )
+                self$res_block2 <- resnet_block(blocks[[1]],
+                                                blocks[[2]],
+                                                kernels
+                )
+                self$res_block3 <- resnet_block(blocks[[2]],
+                                                blocks[[3]],
+                                                kernels
+                )
                 self$gap <- torch::nn_adaptive_avg_pool1d(output_size = n_bands)
 
                 # flatten 3D tensor to 2D tensor
                 self$flatten <- torch::nn_flatten()
                 # classification using softmax
                 self$softmax <- torch::nn_sequential(
-                    torch::nn_linear(blocks[3] * n_bands, n_labels),
+                    torch::nn_linear(blocks[[3]] * n_bands, n_labels),
                     torch::nn_softmax(dim = -1)
                 )
             },
@@ -346,7 +358,7 @@ sits_resnet <- function(samples = NULL,
                 verbose = verbose
             )
         # Serialize model
-        serialized_model <- .torch_serialize_model(torch_model$model)
+        serialized_model <- .torch_serialize_model(torch_model[["model"]])
 
         # Function that predicts labels of input values
         predict_fun <- function(values) {
@@ -356,9 +368,9 @@ sits_resnet <- function(samples = NULL,
             # Note: function does not work on MacOS
             suppressWarnings(torch::torch_set_num_threads(1))
             # Unserialize model
-            torch_model$model <- .torch_unserialize_model(serialized_model)
+            torch_model[["model"]] <- .torch_unserialize_model(serialized_model)
             # Used to check values (below)
-            input_pixels <- nrow(values)
+            n_input_pixels <- nrow(values)
             # Transform input into a 3D tensor
             # Reshape the 2D matrix into a 3D array
             n_samples <- nrow(values)
@@ -369,14 +381,29 @@ sits_resnet <- function(samples = NULL,
             values <- array(
                 data = as.matrix(values), dim = c(n_samples, n_times, n_bands)
             )
-            # Do classification
-            values <- stats::predict(object = torch_model, values)
-            # Convert to tensor cpu to support GPU processing
+            # if CUDA is available, transform to torch data set
+            # Load into GPU
+            if (torch::cuda_is_available()) {
+                values <- .as_dataset(values)
+                # We need to transform in a dataloader to use the batch size
+                values <- torch::dataloader(
+                    values, batch_size = 2^15
+                )
+                # Do GPU classification
+                values <- .try(
+                    stats::predict(object = torch_model, values),
+                    .msg_error = .conf("messages", ".check_gpu_memory_size")
+                )
+            } else {
+                # Do CPU classification
+                values <- stats::predict(object = torch_model, values)
+            }
+            # Convert to tensor CPU
             values <- torch::as_array(
                 x = torch::torch_tensor(values, device = "cpu")
             )
             .check_processed_values(
-                values = values, input_pixels = input_pixels
+                values = values, n_input_pixels = n_input_pixels
             )
             # Update the columns names to labels
             colnames(values) <- labels
