@@ -1,13 +1,9 @@
 library(sits)
 
-# load the sitsdata library
 # load the sitsdata library
 if (!requireNamespace("sitsdata", quietly = TRUE)) {
-    stop(
-        paste0(
-            "Please install package sitsdata\n",
-            "Please call devtools::install_github('e-sensing/sitsdata')"
-        ),
+    stop("Please install package sitsdata\n",
+         "Please call devtools::install_github('e-sensing/sitsdata')",
         call. = FALSE
     )
 }
