@@ -61,22 +61,16 @@ test_that("Combine predictions", {
     expect_true(all(abs(avg - avg2)) < 3)
 
     # Recovery
-    # test Recovery
-    out <- capture_messages({
-        expect_message(
-            object = {
-                sits_combine_predictions(
-                    cubes = pred_cubes,
-                    type = "average",
-                    output_dir = output_dir,
-                    version = "comb_rfor_xgb_avg"
-                )
-            },
-            regexp = "Recovery"
+    Sys.setenv("SITS_DOCUMENTATION_MODE" = "FALSE")
+    expect_message({
+        object <- sits_combine_predictions(
+            cubes = pred_cubes,
+            type = "average",
+            output_dir = output_dir,
+            version = "comb_rfor_xgb_avg"
         )
-    })
-    expect_true(grepl("output_dir", out[1]))
-
+    }
+    )
     # combine predictions
     uncert_rfor <- sits_uncertainty(
         cube = probs_rfor_cube,
