@@ -140,5 +140,5 @@ test_that("file_info errors", {
     # file info
     expect_s3_class(.fi(s2_cube), "tbl_df")
 
-    expect_error(.check_is_regular(s2_cube))
+    expect_false(.cube_is_regular(s2_cube))
 })
