@@ -86,7 +86,7 @@ test_that("bbox as sf", {
         .default = NULL
     )
     testthat::skip_if(purrr::is_null(s2_cube_s2a),
-                      message = "BDC is not accessible"
+                      message = "MPC is not accessible"
     )
     expect_warning(sits_bbox(s2_cube_s2a))
 
