@@ -1,6 +1,6 @@
 test_that("View", {
-    v <- sits_view(cerrado_2classes)
-    expect_true("leaflet" %in% class(v))
+    v1 <- sits_view(cerrado_2classes)
+    expect_true("leaflet" %in% class(v1))
     expect_error(
         sits_view(cerrado_2classes,
                   legend = c("Cerrado" = "green"))
@@ -50,10 +50,6 @@ test_that("View", {
         progress = FALSE,
         version = "v_2"
     )
-    v2_probs <- sits_view(modis_probs)
-    expect_true("leaflet" %in% class(v2_probs))
-    expect_true(grepl("EPSG3857", v2_probs$x$options$crs$crsClass))
-    expect_equal(v2_probs$x$calls[[6]]$args[[6]], "probs Forest")
 
     # create a class cube
     modis_label <- sits_label_classification(modis_probs,
@@ -64,15 +60,11 @@ test_that("View", {
     v3 <- sits_view(modis_label)
     expect_true(grepl("EPSG3857", v3$x$options$crs$crsClass))
     expect_true(
-        all(v3$x$calls[[6]]$args[[1]]$labels %in% c(
+        all(v3$x$calls[[7]]$args[[1]]$labels %in% c(
             "Cerrado", "Pasture",
             "Forest", "Soy_Corn"
         ))
     )
-    v3_probs <- sits_view(modis_probs, class_cube = modis_label)
-    expect_true(grepl("EPSG3857", v3_probs$x$options$crs$crsClass))
-    expect_equal(v3_probs$x$calls[[6]]$args[[6]], "probs Forest")
-
     # view false color data cube and class cube together
     v4 <- sits_view(modis_cube,
         band = "NDVI",
@@ -127,18 +119,18 @@ test_that("View", {
         ),
         output_dir = tempdir()
     )
-    v7 <- sits_view(segments)
+    v7 <- sits_view(segments, band = "NDVI")
     expect_true(grepl("EPSG3857", v7$x$options$crs$crsClass))
     expect_equal(v7$x$calls[[1]]$method, "addProviderTiles")
     expect_equal(v7$x$calls[[1]]$args[[1]], "GeoportailFrance.orthos")
-    expect_equal(v7$x$calls[[5]]$method, "addPolygons")
+    expect_equal(v7$x$calls[[5]]$method, "addRasterImage")
 
     v8 <- sits_view(segments, band = "NDVI")
     expect_true(grepl("EPSG3857", v8$x$options$crs$crsClass))
-    expect_equal(v8$x$calls[[1]]$method, "addProviderTiles")
-    expect_equal(v8$x$calls[[1]]$args[[1]], "GeoportailFrance.orthos")
-    expect_equal(v8$x$calls[[5]]$method, "addRasterImage")
-    expect_equal(v8$x$calls[[6]]$method, "addPolygons")
+    expect_identical(v8$x$calls[[1]]$method, "addProviderTiles")
+    expect_identical(v8$x$calls[[1]]$args[[1]], "GeoportailFrance.orthos")
+    expect_identical(v8$x$calls[[5]]$method, "addRasterImage")
+    expect_identical(v8$x$calls[[6]]$method, "addPolygons")
 
     probs_segs <- sits_classify(
         data = segments,
@@ -159,13 +151,13 @@ test_that("View", {
         version = "v_segs_test"
     )
 
-    v9 <- sits_view(class_segs, class_cube = modis_label)
+    v9 <- sits_view(class_segs, band = "NDVI", class_cube = modis_label)
     expect_true(grepl("EPSG3857", v9$x$options$crs$crsClass))
-    expect_equal(v9$x$calls[[1]]$method, "addProviderTiles")
-    expect_equal(v9$x$calls[[1]]$args[[1]], "GeoportailFrance.orthos")
-    expect_equal(v9$x$calls[[5]]$method, "addPolygons")
-    expect_equal(v9$x$calls[[6]]$method, "addPolygons")
-    expect_equal(v9$x$calls[[7]]$method, "addRasterImage")
+    expect_identical(v9$x$calls[[1]]$method, "addProviderTiles")
+    expect_identical(v9$x$calls[[1]]$args[[1]], "GeoportailFrance.orthos")
+    expect_identical(v9$x$calls[[5]]$method, "addRasterImage")
+    expect_identical(v9$x$calls[[6]]$method, "addPolygons")
+    expect_identical(v9$x$calls[[7]]$method, "addPolygons")
 
 
     cbers_cube <- tryCatch(
@@ -195,24 +187,26 @@ test_that("View", {
                     blue = "B13",
                     dates = "2018-08-29")
 
-    expect_equal(v_cb$x$options$crs$crsClass, "L.CRS.EPSG3857")
-    expect_equal(v_cb$x$calls[[1]]$args[[1]], "GeoportailFrance.orthos")
-    expect_equal(v_cb$x$calls[[5]]$method, "addRasterImage")
-    expect_equal(v_cb$x$calls[[6]]$args[[5]], "007005 2018-08-29")
+    expect_identical(v_cb$x$options$crs$crsClass, "L.CRS.EPSG3857")
+    expect_identical(v_cb$x$calls[[1]]$args[[1]], "GeoportailFrance.orthos")
+    expect_identical(v_cb$x$calls[[5]]$method, "addRasterImage")
+    expect_identical(v_cb$x$calls[[6]]$args[[5]], "007005 2018-08-29")
 
-    expect_true(all(file.remove(unlist(modis_uncert$file_info[[1]]$path))))
-    expect_true(all(file.remove(unlist(modis_probs$file_info[[1]]$path))))
-    expect_true(all(file.remove(unlist(modis_label$file_info[[1]]$path))))
+    expect_true(all(file.remove(unlist(modis_uncert$file_info[[1]][["path"]]))))
+    expect_true(all(file.remove(unlist(modis_probs$file_info[[1]][["path"]]))))
+    expect_true(all(file.remove(unlist(modis_label$file_info[[1]][["path"]]))))
 })
 test_that("View SOM map", {
     set.seed(2903)
-    som_map <- sits_som_map(
-        samples_modis_ndvi,
-        grid_xdim = 4,
-        grid_ydim = 4
-    )
-    v <- sits_view(som_map, id_neurons = c(1:5))
+    expect_warning({
+        som_map <- sits_som_map(
+            samples_modis_ndvi,
+            grid_xdim = 4,
+            grid_ydim = 4
+        )
+    })
+    v <- sits_view(som_map, id_neurons = 1:5)
 
-    expect_true(grepl("EPSG3857", v$x$options$crs$crsClass))
-    expect_equal(v$x$calls[[1]]$method, "addProviderTiles")
+    expect_true(grepl("EPSG3857", v[["x"]][["options"]][["crs"]][["crsClass"]]))
+    expect_identical(v[["x"]][["calls"]][[1]][["method"]], "addProviderTiles")
 })
